

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0007160","cell-matrix adhesion",0.051,0.8247,0.969,0.000,"cell-matrix adhesion"),
c("GO:0070527","platelet aggregation",0.011,0.7754,0.659,0.621,"cell-matrix adhesion"),
c("GO:0007157","heterophilic cell-cell adhesion via plasma membrane cell adhesion molecules",0.008,0.7223,0.971,0.645,"cell-matrix adhesion"),
c("GO:0007626","locomotory behavior",0.061,0.7499,0.994,0.000,"locomotory behavior"),
c("GO:1901537","positive regulation of DNA demethylation",0.000,0.8646,0.793,0.000,"positive regulation of DNA demethylation"),
c("GO:0008063","Toll signaling pathway",0.007,0.8589,0.760,0.114,"positive regulation of DNA demethylation"),
c("GO:0042264","peptidyl-aspartic acid hydroxylation",0.000,0.8462,0.912,0.158,"positive regulation of DNA demethylation"),
c("GO:0032088","negative regulation of NF-kappaB transcription factor activity",0.014,0.8460,0.781,0.177,"positive regulation of DNA demethylation"),
c("GO:0042981","regulation of apoptotic process",0.313,0.7482,0.784,0.185,"positive regulation of DNA demethylation"),
c("GO:0050821","protein stabilization",0.045,0.7103,0.864,0.187,"positive regulation of DNA demethylation"),
c("GO:0043631","RNA polyadenylation",0.057,0.8029,0.915,0.189,"positive regulation of DNA demethylation"),
c("GO:0014823","response to activity",0.005,0.7312,0.904,0.190,"positive regulation of DNA demethylation"),
c("GO:0033198","response to ATP",0.009,0.8492,0.868,0.196,"positive regulation of DNA demethylation"),
c("GO:0006426","glycyl-tRNA aminoacylation",0.066,0.7710,0.803,0.209,"positive regulation of DNA demethylation"),
c("GO:0000012","single strand break repair",0.004,0.8552,0.835,0.224,"positive regulation of DNA demethylation"),
c("GO:0038194","thyroid-stimulating hormone signaling pathway",0.001,0.8175,0.805,0.239,"positive regulation of DNA demethylation"),
c("GO:0006596","polyamine biosynthetic process",0.117,0.7543,0.916,0.240,"positive regulation of DNA demethylation"),
c("GO:0043484","regulation of RNA splicing",0.040,0.8086,0.817,0.248,"positive regulation of DNA demethylation"),
c("GO:1990961","drug transmembrane export",0.000,0.7245,0.846,0.263,"positive regulation of DNA demethylation"),
c("GO:0007249","I-kappaB kinase/NF-kappaB signaling",0.057,0.8377,0.752,0.297,"positive regulation of DNA demethylation"),
c("GO:0007232","osmosensory signaling pathway via Sho1 osmosensor",0.001,0.7657,0.796,0.311,"positive regulation of DNA demethylation"),
c("GO:0006099","tricarboxylic acid cycle",0.469,0.7064,0.844,0.349,"positive regulation of DNA demethylation"),
c("GO:0051454","intracellular pH elevation",0.002,0.6999,0.830,0.350,"positive regulation of DNA demethylation"),
c("GO:0071277","cellular response to calcium ion",0.009,0.7026,0.848,0.363,"positive regulation of DNA demethylation"),
c("GO:0002092","positive regulation of receptor internalization",0.004,0.8564,0.653,0.378,"positive regulation of DNA demethylation"),
c("GO:0006478","peptidyl-tyrosine sulfation",0.010,0.8293,0.893,0.386,"positive regulation of DNA demethylation"),
c("GO:0042754","negative regulation of circadian rhythm",0.003,0.7457,0.865,0.395,"positive regulation of DNA demethylation"),
c("GO:0032889","regulation of vacuole fusion, non-autophagic",0.005,0.8534,0.730,0.408,"positive regulation of DNA demethylation"),
c("GO:0048015","phosphatidylinositol-mediated signaling",0.061,0.8127,0.751,0.415,"positive regulation of DNA demethylation"),
c("GO:0051489","regulation of filopodium assembly",0.009,0.8518,0.734,0.422,"positive regulation of DNA demethylation"),
c("GO:0016246","RNA interference",0.011,0.7496,0.775,0.428,"positive regulation of DNA demethylation"),
c("GO:0006413","translational initiation",0.518,0.7188,0.866,0.430,"positive regulation of DNA demethylation"),
c("GO:0030950","establishment or maintenance of actin cytoskeleton polarity",0.010,0.8511,0.779,0.440,"positive regulation of DNA demethylation"),
c("GO:0000724","double-strand break repair via homologous recombination",0.120,0.7680,0.793,0.441,"positive regulation of DNA demethylation"),
c("GO:0035494","SNARE complex disassembly",0.004,0.8478,0.772,0.443,"positive regulation of DNA demethylation"),
c("GO:0008592","regulation of Toll signaling pathway",0.001,0.8534,0.753,0.445,"positive regulation of DNA demethylation"),
c("GO:1990504","dense core granule exocytosis",0.005,0.8510,0.825,0.448,"positive regulation of DNA demethylation"),
c("GO:0070072","vacuolar proton-transporting V-type ATPase complex assembly",0.013,0.8414,0.854,0.448,"positive regulation of DNA demethylation"),
c("GO:0007265","Ras protein signal transduction",0.225,0.8056,0.720,0.458,"positive regulation of DNA demethylation"),
c("GO:0001732","formation of cytoplasmic translation initiation complex",0.004,0.7770,0.803,0.458,"positive regulation of DNA demethylation"),
c("GO:0007205","protein kinase C-activating G-protein coupled receptor signaling pathway",0.018,0.8072,0.773,0.463,"positive regulation of DNA demethylation"),
c("GO:0031123","RNA 3'-end processing",0.145,0.7641,0.902,0.463,"positive regulation of DNA demethylation"),
c("GO:0032933","SREBP signaling pathway",0.008,0.8480,0.701,0.469,"positive regulation of DNA demethylation"),
c("GO:0007166","cell surface receptor signaling pathway",0.920,0.7185,0.711,0.470,"positive regulation of DNA demethylation"),
c("GO:0101030","tRNA-guanine transglycosylation",0.038,0.7478,0.880,0.474,"positive regulation of DNA demethylation"),
c("GO:1900449","regulation of glutamate receptor signaling pathway",0.008,0.8493,0.731,0.488,"positive regulation of DNA demethylation"),
c("GO:0050688","regulation of defense response to virus",0.019,0.8462,0.767,0.491,"positive regulation of DNA demethylation"),
c("GO:0061588","calcium activated phospholipid scrambling",0.004,0.8211,0.756,0.492,"positive regulation of DNA demethylation"),
c("GO:0006979","response to oxidative stress",0.575,0.7087,0.857,0.495,"positive regulation of DNA demethylation"),
c("GO:0045737","positive regulation of cyclin-dependent protein serine/threonine kinase activity",0.018,0.8457,0.687,0.504,"positive regulation of DNA demethylation"),
c("GO:0006901","vesicle coating",0.012,0.8452,0.797,0.510,"positive regulation of DNA demethylation"),
c("GO:0000165","MAPK cascade",0.245,0.7917,0.649,0.511,"positive regulation of DNA demethylation"),
c("GO:0018105","peptidyl-serine phosphorylation",0.087,0.8150,0.864,0.511,"positive regulation of DNA demethylation"),
c("GO:0033209","tumor necrosis factor-mediated signaling pathway",0.016,0.8486,0.726,0.517,"positive regulation of DNA demethylation"),
c("GO:0032007","negative regulation of TOR signaling",0.016,0.8371,0.710,0.519,"positive regulation of DNA demethylation"),
c("GO:0006772","thiamine metabolic process",0.252,0.7262,0.834,0.519,"positive regulation of DNA demethylation"),
c("GO:0035590","purinergic nucleotide receptor signaling pathway",0.013,0.8452,0.751,0.525,"positive regulation of DNA demethylation"),
c("GO:0030073","insulin secretion",0.031,0.8474,0.680,0.536,"positive regulation of DNA demethylation"),
c("GO:0007186","G-protein coupled receptor signaling pathway",0.882,0.7117,0.712,0.538,"positive regulation of DNA demethylation"),
c("GO:0042058","regulation of epidermal growth factor receptor signaling pathway",0.015,0.8296,0.715,0.539,"positive regulation of DNA demethylation"),
c("GO:0090084","negative regulation of inclusion body assembly",0.002,0.7491,0.769,0.540,"positive regulation of DNA demethylation"),
c("GO:0007264","small GTPase mediated signal transduction",0.485,0.7631,0.716,0.545,"positive regulation of DNA demethylation"),
c("GO:0038179","neurotrophin signaling pathway",0.007,0.7920,0.738,0.547,"positive regulation of DNA demethylation"),
c("GO:0030224","monocyte differentiation",0.006,0.8225,0.756,0.557,"positive regulation of DNA demethylation"),
c("GO:0071300","cellular response to retinoic acid",0.008,0.7891,0.842,0.562,"positive regulation of DNA demethylation"),
c("GO:0048268","clathrin coat assembly",0.018,0.8320,0.851,0.564,"positive regulation of DNA demethylation"),
c("GO:0030433","ER-associated ubiquitin-dependent protein catabolic process",0.049,0.8212,0.695,0.570,"positive regulation of DNA demethylation"),
c("GO:0000272","polysaccharide catabolic process",0.288,0.7326,0.924,0.572,"positive regulation of DNA demethylation"),
c("GO:0007219","Notch signaling pathway",0.061,0.8134,0.729,0.575,"positive regulation of DNA demethylation"),
c("GO:0071526","semaphorin-plexin signaling pathway",0.019,0.7257,0.747,0.581,"positive regulation of DNA demethylation"),
c("GO:0000147","actin cortical patch assembly",0.005,0.7443,0.788,0.582,"positive regulation of DNA demethylation"),
c("GO:0001522","pseudouridine synthesis",0.350,0.7175,0.872,0.585,"positive regulation of DNA demethylation"),
c("GO:0061726","mitochondrion disassembly",0.025,0.8429,0.776,0.589,"positive regulation of DNA demethylation"),
c("GO:0008593","regulation of Notch signaling pathway",0.026,0.7319,0.712,0.594,"positive regulation of DNA demethylation"),
c("GO:0051260","protein homooligomerization",0.106,0.7840,0.836,0.594,"positive regulation of DNA demethylation"),
c("GO:0006289","nucleotide-excision repair",0.310,0.7239,0.781,0.594,"positive regulation of DNA demethylation"),
c("GO:0032786","positive regulation of DNA-templated transcription, elongation",0.037,0.8028,0.769,0.602,"positive regulation of DNA demethylation"),
c("GO:0006357","regulation of transcription from RNA polymerase II promoter",1.273,0.7059,0.760,0.605,"positive regulation of DNA demethylation"),
c("GO:0010923","negative regulation of phosphatase activity",0.018,0.8131,0.774,0.611,"positive regulation of DNA demethylation"),
c("GO:0034599","cellular response to oxidative stress",0.224,0.7468,0.804,0.613,"positive regulation of DNA demethylation"),
c("GO:0006325","chromatin organization",0.668,0.7244,0.831,0.616,"positive regulation of DNA demethylation"),
c("GO:2000323","negative regulation of glucocorticoid receptor signaling pathway",0.001,0.7656,0.724,0.619,"positive regulation of DNA demethylation"),
c("GO:0032482","Rab protein signal transduction",0.002,0.7183,0.784,0.623,"positive regulation of DNA demethylation"),
c("GO:0043123","positive regulation of I-kappaB kinase/NF-kappaB signaling",0.037,0.8354,0.686,0.623,"positive regulation of DNA demethylation"),
c("GO:0007229","integrin-mediated signaling pathway",0.056,0.8006,0.730,0.624,"positive regulation of DNA demethylation"),
c("GO:0006589","octopamine biosynthetic process",0.001,0.7463,0.799,0.625,"positive regulation of DNA demethylation"),
c("GO:0016598","protein arginylation",0.017,0.8198,0.874,0.627,"positive regulation of DNA demethylation"),
c("GO:1901187","regulation of ephrin receptor signaling pathway",0.001,0.7839,0.747,0.635,"positive regulation of DNA demethylation"),
c("GO:0034765","regulation of ion transmembrane transport",0.197,0.7744,0.794,0.642,"positive regulation of DNA demethylation"),
c("GO:0051017","actin filament bundle assembly",0.045,0.8245,0.759,0.657,"positive regulation of DNA demethylation"),
c("GO:0006313","transposition, DNA-mediated",0.413,0.7108,0.823,0.662,"positive regulation of DNA demethylation"),
c("GO:0045087","innate immune response",0.148,0.7941,0.852,0.681,"positive regulation of DNA demethylation"),
c("GO:0043547","positive regulation of GTPase activity",0.470,0.7559,0.832,0.681,"positive regulation of DNA demethylation"),
c("GO:1900407","regulation of cellular response to oxidative stress",0.014,0.7550,0.750,0.686,"positive regulation of DNA demethylation"),
c("GO:0007029","endoplasmic reticulum organization",0.032,0.8161,0.847,0.686,"positive regulation of DNA demethylation"),
c("GO:0030513","positive regulation of BMP signaling pathway",0.009,0.7126,0.641,0.692,"positive regulation of DNA demethylation"),
c("GO:0038109","Kit signaling pathway",0.001,0.7699,0.754,0.692,"positive regulation of DNA demethylation"),
c("GO:0006417","regulation of translation",0.692,0.7176,0.741,0.697,"positive regulation of DNA demethylation"),
c("GO:0031532","actin cytoskeleton reorganization",0.028,0.7503,0.773,0.698,"positive regulation of DNA demethylation"),
c("GO:0045033","peroxisome inheritance",0.004,0.8588,0.870,0.013,"peroxisome inheritance"),
c("GO:0035518","histone H2A monoubiquitination",0.003,0.8487,0.819,0.235,"peroxisome inheritance"),
c("GO:0070830","bicellular tight junction assembly",0.011,0.8260,0.810,0.252,"peroxisome inheritance"),
c("GO:0046777","protein autophosphorylation",0.077,0.7323,0.874,0.267,"peroxisome inheritance"),
c("GO:0030382","sperm mitochondrion organization",0.001,0.8450,0.875,0.291,"peroxisome inheritance"),
c("GO:0050808","synapse organization",0.070,0.7896,0.803,0.298,"peroxisome inheritance"),
c("GO:0009658","chloroplast organization",0.019,0.8345,0.858,0.342,"peroxisome inheritance"),
c("GO:0097435","supramolecular fiber organization",0.345,0.7247,0.782,0.377,"peroxisome inheritance"),
c("GO:0030261","chromosome condensation",0.108,0.7616,0.840,0.417,"peroxisome inheritance"),
c("GO:0007005","mitochondrion organization",0.418,0.7511,0.829,0.521,"peroxisome inheritance"),
c("GO:0000209","protein polyubiquitination",0.066,0.8153,0.890,0.586,"peroxisome inheritance"),
c("GO:0034968","histone lysine methylation",0.100,0.7882,0.775,0.640,"peroxisome inheritance"),
c("GO:0018106","peptidyl-histidine phosphorylation",0.265,0.6909,0.856,0.645,"peroxisome inheritance"),
c("GO:0006914","autophagy",0.230,0.7751,0.962,0.020,"autophagy"),
c("GO:0030242","pexophagy",0.009,0.8101,0.954,0.021,"pexophagy"),
c("GO:0006801","superoxide metabolic process",0.144,0.7547,0.953,0.029,"superoxide metabolism"),
c("GO:0001935","endothelial cell proliferation",0.022,0.8561,0.921,0.036,"endothelial cell proliferation"),
c("GO:0048662","negative regulation of smooth muscle cell proliferation",0.007,0.7871,0.819,0.612,"endothelial cell proliferation"),
c("GO:0008283","cell proliferation",0.394,0.7743,0.923,0.059,"cell proliferation"),
c("GO:0006516","glycoprotein catabolic process",0.008,0.8508,0.899,0.060,"glycoprotein catabolism"),
c("GO:0042737","drug catabolic process",0.001,0.6951,0.940,0.323,"glycoprotein catabolism"),
c("GO:0006040","amino sugar metabolic process",0.244,0.7264,0.960,0.335,"glycoprotein catabolism"),
c("GO:0006030","chitin metabolic process",0.077,0.7848,0.932,0.392,"glycoprotein catabolism"),
c("GO:0000184","nuclear-transcribed mRNA catabolic process, nonsense-mediated decay",0.030,0.8048,0.887,0.492,"glycoprotein catabolism"),
c("GO:0006562","proline catabolic process",0.033,0.7901,0.824,0.560,"glycoprotein catabolism"),
c("GO:0006370","7-methylguanosine mRNA capping",0.022,0.7621,0.910,0.580,"glycoprotein catabolism"),
c("GO:0009254","peptidoglycan turnover",0.053,0.7711,0.933,0.637,"glycoprotein catabolism"),
c("GO:1902222","erythrose 4-phosphate/phosphoenolpyruvate family amino acid catabolic process",0.031,0.7872,0.829,0.638,"glycoprotein catabolism"),
c("GO:0009074","aromatic amino acid family catabolic process",0.116,0.7369,0.812,0.677,"glycoprotein catabolism"),
c("GO:0016540","protein autoprocessing",0.011,0.7641,0.934,0.061,"protein autoprocessing"),
c("GO:0007298","border follicle cell migration",0.007,0.8579,0.717,0.079,"border follicle cell migration"),
c("GO:0000086","G2/M transition of mitotic cell cycle",0.052,0.7937,0.867,0.109,"border follicle cell migration"),
c("GO:0033227","dsRNA transport",0.005,0.8542,0.869,0.142,"border follicle cell migration"),
c("GO:0006851","mitochondrial calcium ion transport",0.005,0.8458,0.929,0.145,"border follicle cell migration"),
c("GO:0006858","extracellular transport",0.008,0.8134,0.945,0.148,"border follicle cell migration"),
c("GO:0006081","cellular aldehyde metabolic process",0.753,0.6974,0.849,0.150,"border follicle cell migration"),
c("GO:0016197","endosomal transport",0.131,0.7826,0.935,0.178,"border follicle cell migration"),
c("GO:0007034","vacuolar transport",0.133,0.7819,0.935,0.216,"border follicle cell migration"),
c("GO:0016192","vesicle-mediated transport",1.085,0.6913,0.925,0.257,"border follicle cell migration"),
c("GO:1902476","chloride transmembrane transport",0.047,0.7706,0.923,0.316,"border follicle cell migration"),
c("GO:0006836","neurotransmitter transport",0.113,0.6998,0.863,0.324,"border follicle cell migration"),
c("GO:0006622","protein targeting to lysosome",0.004,0.8530,0.909,0.338,"border follicle cell migration"),
c("GO:0045176","apical protein localization",0.003,0.7323,0.931,0.344,"border follicle cell migration"),
c("GO:0032418","lysosome localization",0.010,0.8513,0.922,0.393,"border follicle cell migration"),
c("GO:1904888","cranial skeletal system development",0.021,0.7119,0.886,0.398,"border follicle cell migration"),
c("GO:0010842","retina layer formation",0.006,0.8508,0.804,0.407,"border follicle cell migration"),
c("GO:0035264","multicellular organism growth",0.041,0.8450,0.795,0.453,"border follicle cell migration"),
c("GO:0071427","mRNA-containing ribonucleoprotein complex export from nucleus",0.056,0.7984,0.912,0.463,"border follicle cell migration"),
c("GO:0045599","negative regulation of fat cell differentiation",0.009,0.8516,0.718,0.470,"border follicle cell migration"),
c("GO:0033555","multicellular organismal response to stress",0.014,0.6903,0.747,0.472,"border follicle cell migration"),
c("GO:0003015","heart process",0.046,0.8382,0.868,0.472,"border follicle cell migration"),
c("GO:0051668","localization within membrane",0.023,0.7062,0.921,0.481,"border follicle cell migration"),
c("GO:0016199","axon midline choice point recognition",0.002,0.8519,0.638,0.499,"border follicle cell migration"),
c("GO:0001894","tissue homeostasis",0.044,0.8269,0.728,0.506,"border follicle cell migration"),
c("GO:0003341","cilium movement",0.023,0.8307,0.846,0.512,"border follicle cell migration"),
c("GO:0006814","sodium ion transport",0.305,0.7298,0.916,0.513,"border follicle cell migration"),
c("GO:0045053","protein retention in Golgi apparatus",0.007,0.7808,0.755,0.513,"border follicle cell migration"),
c("GO:0001649","osteoblast differentiation",0.040,0.8455,0.758,0.517,"border follicle cell migration"),
c("GO:0001889","liver development",0.023,0.8347,0.797,0.531,"border follicle cell migration"),
c("GO:0007113","endomitotic cell cycle",0.001,0.6981,0.889,0.542,"border follicle cell migration"),
c("GO:0060541","respiratory system development",0.054,0.8231,0.793,0.543,"border follicle cell migration"),
c("GO:0009952","anterior/posterior pattern specification",0.059,0.8126,0.790,0.548,"border follicle cell migration"),
c("GO:0030317","flagellated sperm motility",0.017,0.7741,0.827,0.552,"border follicle cell migration"),
c("GO:0061817","endoplasmic reticulum-plasma membrane tethering",0.000,0.8226,0.933,0.563,"border follicle cell migration"),
c("GO:0016322","neuron remodeling",0.005,0.7068,0.771,0.563,"border follicle cell migration"),
c("GO:0048863","stem cell differentiation",0.047,0.7286,0.785,0.572,"border follicle cell migration"),
c("GO:0031016","pancreas development",0.021,0.8322,0.798,0.573,"border follicle cell migration"),
c("GO:0006888","ER to Golgi vesicle-mediated transport",0.125,0.7820,0.893,0.577,"border follicle cell migration"),
c("GO:0009405","pathogenesis",0.095,0.6916,0.987,0.589,"border follicle cell migration"),
c("GO:0001578","microtubule bundle formation",0.027,0.8219,0.768,0.601,"border follicle cell migration"),
c("GO:0060027","convergent extension involved in gastrulation",0.006,0.8484,0.812,0.601,"border follicle cell migration"),
c("GO:0030539","male genitalia development",0.006,0.7616,0.808,0.604,"border follicle cell migration"),
c("GO:2001222","regulation of neuron migration",0.006,0.8520,0.664,0.607,"border follicle cell migration"),
c("GO:0051726","regulation of cell cycle",0.547,0.7311,0.763,0.611,"border follicle cell migration"),
c("GO:0001817","regulation of cytokine production",0.108,0.7924,0.725,0.611,"border follicle cell migration"),
c("GO:0051216","cartilage development",0.043,0.8197,0.784,0.612,"border follicle cell migration"),
c("GO:0015698","inorganic anion transport",0.872,0.6920,0.911,0.622,"border follicle cell migration"),
c("GO:0042147","retrograde transport, endosome to Golgi",0.055,0.7046,0.899,0.630,"border follicle cell migration"),
c("GO:0007601","visual perception",0.050,0.7843,0.867,0.653,"border follicle cell migration"),
c("GO:0007420","brain development",0.142,0.7837,0.768,0.673,"border follicle cell migration"),
c("GO:0016477","cell migration",0.293,0.7698,0.795,0.693,"border follicle cell migration"),
c("GO:0035293","chitin-based larval cuticle pattern formation",0.001,0.7720,0.834,0.695,"border follicle cell migration"),
c("GO:0006887","exocytosis",0.210,0.7714,0.785,0.696,"border follicle cell migration"),
c("GO:0070050","neuron cellular homeostasis",0.003,0.7756,0.822,0.697,"border follicle cell migration"),
c("GO:0098507","polynucleotide 5' dephosphorylation",0.007,0.8440,0.906,0.082,"polynucleotide 5prime dephosphorylation"),
c("GO:0036092","phosphatidylinositol-3-phosphate biosynthetic process",0.011,0.8285,0.835,0.189,"polynucleotide 5prime dephosphorylation"),
c("GO:0061370","testosterone biosynthetic process",0.001,0.7841,0.853,0.370,"polynucleotide 5prime dephosphorylation"),
c("GO:0009190","cyclic nucleotide biosynthetic process",0.182,0.7511,0.802,0.396,"polynucleotide 5prime dephosphorylation"),
c("GO:0042420","dopamine catabolic process",0.002,0.7348,0.905,0.427,"polynucleotide 5prime dephosphorylation"),
c("GO:0016042","lipid catabolic process",0.401,0.7209,0.854,0.440,"polynucleotide 5prime dephosphorylation"),
c("GO:0010898","positive regulation of triglyceride catabolic process",0.003,0.8243,0.750,0.520,"polynucleotide 5prime dephosphorylation"),
c("GO:0015937","coenzyme A biosynthetic process",0.154,0.7424,0.794,0.558,"polynucleotide 5prime dephosphorylation"),
c("GO:0046856","phosphatidylinositol dephosphorylation",0.048,0.8081,0.819,0.676,"polynucleotide 5prime dephosphorylation"),
c("GO:0006470","protein dephosphorylation",0.585,0.7178,0.855,0.678,"polynucleotide 5prime dephosphorylation"),
c("GO:0006646","phosphatidylethanolamine biosynthetic process",0.028,0.7328,0.827,0.682,"polynucleotide 5prime dephosphorylation"),
c("GO:0098725","symmetric cell division",0.001,0.7723,0.906,0.087,"symmetric cell division"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
