

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0003344","pericardium morphogenesis",0.002,0.8639,0.745,0.000,"pericardium morphogenesis"),
c("GO:0001709","cell fate determination",0.015,0.8127,0.744,0.360,"pericardium morphogenesis"),
c("GO:0002024","diet induced thermogenesis",0.002,0.6014,0.773,0.363,"pericardium morphogenesis"),
c("GO:0048942","posterior lateral line nerve glial cell morphogenesis involved in differentiation",0.000,0.5318,0.727,0.405,"pericardium morphogenesis"),
c("GO:0010171","body morphogenesis",0.015,0.4308,0.778,0.421,"pericardium morphogenesis"),
c("GO:0035264","multicellular organism growth",0.041,0.8450,0.735,0.424,"pericardium morphogenesis"),
c("GO:0032689","negative regulation of interferon-gamma production",0.006,0.5308,0.692,0.446,"pericardium morphogenesis"),
c("GO:0007605","sensory perception of sound",0.039,0.4705,0.851,0.466,"pericardium morphogenesis"),
c("GO:1904179","positive regulation of adipose tissue development",0.001,0.6234,0.637,0.470,"pericardium morphogenesis"),
c("GO:0021983","pituitary gland development",0.009,0.8339,0.737,0.480,"pericardium morphogenesis"),
c("GO:0008340","determination of adult lifespan",0.020,0.4395,0.745,0.482,"pericardium morphogenesis"),
c("GO:0030318","melanocyte differentiation",0.008,0.5092,0.756,0.485,"pericardium morphogenesis"),
c("GO:0016203","muscle attachment",0.003,0.4962,0.758,0.487,"pericardium morphogenesis"),
c("GO:0006478","peptidyl-tyrosine sulfation",0.010,0.8305,0.911,0.000,"peptidyl-tyrosine sulfation"),
c("GO:0010467","gene expression",19.671,0.5441,0.938,0.104,"peptidyl-tyrosine sulfation"),
c("GO:0006517","protein deglycosylation",0.008,0.4963,0.919,0.254,"peptidyl-tyrosine sulfation"),
c("GO:0016567","protein ubiquitination",0.523,0.7235,0.891,0.328,"peptidyl-tyrosine sulfation"),
c("GO:0046777","protein autophosphorylation",0.077,0.5257,0.895,0.380,"peptidyl-tyrosine sulfation"),
c("GO:0006895","Golgi to endosome transport",0.012,0.8436,0.881,0.000,"Golgi to endosome transport"),
c("GO:0015698","inorganic anion transport",0.872,0.6884,0.895,0.208,"Golgi to endosome transport"),
c("GO:0006833","water transport",0.014,0.5310,0.882,0.210,"Golgi to endosome transport"),
c("GO:0015833","peptide transport",0.298,0.4881,0.909,0.271,"Golgi to endosome transport"),
c("GO:0016192","vesicle-mediated transport",1.085,0.5320,0.916,0.309,"Golgi to endosome transport"),
c("GO:0015670","carbon dioxide transport",0.001,0.4327,0.891,0.330,"Golgi to endosome transport"),
c("GO:1902965","regulation of protein localization to early endosome",0.001,0.6119,0.787,0.370,"Golgi to endosome transport"),
c("GO:0051660","establishment of centrosome localization",0.001,0.7726,0.916,0.392,"Golgi to endosome transport"),
c("GO:0055085","transmembrane transport",8.916,0.5520,0.899,0.412,"Golgi to endosome transport"),
c("GO:0006622","protein targeting to lysosome",0.004,0.6048,0.891,0.466,"Golgi to endosome transport"),
c("GO:0007160","cell-matrix adhesion",0.051,0.8142,0.962,0.000,"cell-matrix adhesion"),
c("GO:0060233","oenocyte delamination",0.000,0.4698,0.804,0.493,"cell-matrix adhesion"),
c("GO:0007623","circadian rhythm",0.057,0.4374,0.994,0.000,"circadian rhythm"),
c("GO:0007626","locomotory behavior",0.061,0.5505,0.994,0.000,"locomotory behavior"),
c("GO:0023052","signaling",6.765,0.5563,0.995,0.000,"signaling"),
c("GO:0032501","multicellular organismal process",2.373,0.4635,0.994,0.000,"multicellular organismal process"),
c("GO:0032502","developmental process",2.812,0.4375,0.994,0.000,"developmental process"),
c("GO:0032259","methylation",3.103,0.6198,0.987,0.011,"methylation"),
c("GO:0006044","N-acetylglucosamine metabolic process",0.055,0.7801,0.978,0.027,"N-acetylglucosamine metabolism"),
c("GO:0007154","cell communication",7.219,0.5714,0.958,0.028,"cell communication"),
c("GO:0050665","hydrogen peroxide biosynthetic process",0.003,0.8047,0.956,0.030,"hydrogen peroxide biosynthesis"),
c("GO:0046627","negative regulation of insulin receptor signaling pathway",0.007,0.8504,0.689,0.040,"negative regulation of insulin receptor signaling pathway"),
c("GO:0061588","calcium activated phospholipid scrambling",0.004,0.7902,0.782,0.127,"negative regulation of insulin receptor signaling pathway"),
c("GO:0051092","positive regulation of NF-kappaB transcription factor activity",0.025,0.8333,0.703,0.151,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006270","DNA replication initiation",0.141,0.7557,0.916,0.179,"negative regulation of insulin receptor signaling pathway"),
c("GO:0051604","protein maturation",0.293,0.5086,0.926,0.185,"negative regulation of insulin receptor signaling pathway"),
c("GO:0042981","regulation of apoptotic process",0.313,0.7439,0.757,0.193,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006959","humoral immune response",0.035,0.8143,0.889,0.210,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006979","response to oxidative stress",0.575,0.7111,0.879,0.281,"negative regulation of insulin receptor signaling pathway"),
c("GO:0019722","calcium-mediated signaling",0.040,0.8058,0.753,0.291,"negative regulation of insulin receptor signaling pathway"),
c("GO:0030036","actin cytoskeleton organization",0.381,0.7288,0.819,0.309,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006357","regulation of transcription from RNA polymerase II promoter",1.273,0.7016,0.732,0.329,"negative regulation of insulin receptor signaling pathway"),
c("GO:0016071","mRNA metabolic process",0.798,0.4776,0.910,0.336,"negative regulation of insulin receptor signaling pathway"),
c("GO:1902997","negative regulation of neurofibrillary tangle assembly",0.000,0.6244,0.794,0.345,"negative regulation of insulin receptor signaling pathway"),
c("GO:0030198","extracellular matrix organization",0.060,0.5003,0.846,0.375,"negative regulation of insulin receptor signaling pathway"),
c("GO:0071476","cellular hypotonic response",0.003,0.5334,0.887,0.377,"negative regulation of insulin receptor signaling pathway"),
c("GO:0043491","protein kinase B signaling",0.031,0.5462,0.756,0.388,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006396","RNA processing",3.210,0.6225,0.891,0.395,"negative regulation of insulin receptor signaling pathway"),
c("GO:0007186","G-protein coupled receptor signaling pathway",0.882,0.7085,0.698,0.404,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006873","cellular ion homeostasis",0.324,0.5583,0.756,0.410,"negative regulation of insulin receptor signaling pathway"),
c("GO:0097435","supramolecular fiber organization",0.345,0.5501,0.835,0.433,"negative regulation of insulin receptor signaling pathway"),
c("GO:1902771","positive regulation of choline O-acetyltransferase activity",0.000,0.6244,0.850,0.435,"negative regulation of insulin receptor signaling pathway"),
c("GO:0016570","histone modification",0.373,0.4222,0.828,0.437,"negative regulation of insulin receptor signaling pathway"),
c("GO:1901557","response to fenofibrate",0.000,0.4821,0.916,0.456,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006366","transcription from RNA polymerase II promoter",1.430,0.7267,0.888,0.465,"negative regulation of insulin receptor signaling pathway"),
c("GO:0098869","cellular oxidant detoxification",0.784,0.6904,0.853,0.467,"negative regulation of insulin receptor signaling pathway"),
c("GO:0071340","skeletal muscle acetylcholine-gated channel clustering",0.002,0.5989,0.797,0.469,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006950","response to stress",4.575,0.4348,0.873,0.472,"negative regulation of insulin receptor signaling pathway"),
c("GO:0038065","collagen-activated signaling pathway",0.006,0.4550,0.762,0.479,"negative regulation of insulin receptor signaling pathway"),
c("GO:1901666","positive regulation of NAD+ ADP-ribosyltransferase activity",0.000,0.4771,0.844,0.491,"negative regulation of insulin receptor signaling pathway"),
c("GO:1903413","cellular response to bile acid",0.000,0.4854,0.895,0.495,"negative regulation of insulin receptor signaling pathway"),
c("GO:0000724","double-strand break repair via homologous recombination",0.120,0.5241,0.825,0.495,"negative regulation of insulin receptor signaling pathway"),
c("GO:0006658","phosphatidylserine metabolic process",0.014,0.8219,0.862,0.044,"phosphatidylserine metabolism"),
c("GO:0045197","establishment or maintenance of epithelial cell apical/basal polarity",0.008,0.7367,0.897,0.103,"phosphatidylserine metabolism"),
c("GO:0007163","establishment or maintenance of cell polarity",0.099,0.4458,0.893,0.118,"phosphatidylserine metabolism"),
c("GO:0098507","polynucleotide 5' dephosphorylation",0.007,0.8190,0.928,0.192,"phosphatidylserine metabolism"),
c("GO:0006665","sphingolipid metabolic process",0.093,0.7619,0.865,0.444,"phosphatidylserine metabolism"),
c("GO:0010897","negative regulation of triglyceride catabolic process",0.000,0.6134,0.773,0.484,"phosphatidylserine metabolism"),
c("GO:0001676","long-chain fatty acid metabolic process",0.056,0.4980,0.875,0.485,"phosphatidylserine metabolism"),
c("GO:0009102","biotin biosynthetic process",0.081,0.4630,0.850,0.493,"phosphatidylserine metabolism"),
c("GO:0006590","thyroid hormone generation",0.003,0.5323,0.838,0.495,"phosphatidylserine metabolism"),
c("GO:0005975","carbohydrate metabolic process",5.260,0.6007,0.968,0.049,"carbohydrate metabolism"),
c("GO:0050673","epithelial cell proliferation",0.069,0.7709,0.927,0.051,"epithelial cell proliferation"),
c("GO:0006013","mannose metabolic process",0.031,0.8053,0.916,0.093,"mannose metabolism"),
c("GO:0006629","lipid metabolic process",3.522,0.6285,0.893,0.137,"mannose metabolism"),
c("GO:0000050","urea cycle",0.003,0.5139,0.888,0.174,"mannose metabolism"),
c("GO:0006525","arginine metabolic process",0.386,0.7008,0.855,0.235,"mannose metabolism"),
c("GO:0055114","oxidation-reduction process",15.060,0.5339,0.894,0.300,"mannose metabolism"),
c("GO:0006414","translational elongation",0.777,0.4565,0.872,0.339,"mannose metabolism"),
c("GO:0006508","proteolysis",5.223,0.6073,0.917,0.352,"mannose metabolism"),
c("GO:0045493","xylan catabolic process",0.044,0.6594,0.928,0.353,"mannose metabolism"),
c("GO:0006491","N-glycan processing",0.015,0.4243,0.838,0.427,"mannose metabolism"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
