

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0005576","extracellular region",2.375,0.6690,0.994,0.000,"extracellular region"),
c("GO:0005623","cell",53.553,0.6624,0.997,0.000,"cell"),
c("GO:0005913","cell-cell adherens junction",0.028,0.8355,0.964,0.000,"cell-cell adherens junction"),
c("GO:0019033","viral tegument",0.004,0.8436,0.992,0.000,"viral tegument"),
c("GO:0039618","T=pseudo3 icosahedral viral capsid",0.000,0.8152,0.992,0.478,"viral tegument"),
c("GO:0019867","outer membrane",1.018,0.6589,0.982,0.000,"outer membrane"),
c("GO:0030054","cell junction",0.445,0.6862,0.994,0.000,"cell junction"),
c("GO:0032019","mitochondrial cloud",0.000,0.8788,0.802,0.000,"mitochondrial cloud"),
c("GO:0036457","keratohyalin granule",0.000,0.7886,0.849,0.123,"mitochondrial cloud"),
c("GO:0032311","angiogenin-PRI complex",0.000,0.8740,0.792,0.000,"angiogenin-PRI complex"),
c("GO:0005844","polysome",0.037,0.8312,0.740,0.167,"angiogenin-PRI complex"),
c("GO:0097342","ripoptosome",0.002,0.5568,0.716,0.181,"angiogenin-PRI complex"),
c("GO:1990861","Ubp3-Bre5 deubiquitination complex",0.000,0.6303,0.806,0.208,"angiogenin-PRI complex"),
c("GO:1990696","USH2 complex",0.001,0.8710,0.802,0.212,"angiogenin-PRI complex"),
c("GO:0097057","TRAF2-GSTP1 complex",0.001,0.5941,0.804,0.214,"angiogenin-PRI complex"),
c("GO:1990630","IRE1-RACK1-PP2A complex",0.001,0.5783,0.803,0.215,"angiogenin-PRI complex"),
c("GO:0043235","receptor complex",0.115,0.7817,0.798,0.230,"angiogenin-PRI complex"),
c("GO:0000127","transcription factor TFIIIC complex",0.005,0.8466,0.618,0.235,"angiogenin-PRI complex"),
c("GO:1990393","3M complex",0.002,0.7398,0.795,0.244,"angiogenin-PRI complex"),
c("GO:0070695","FHF complex",0.002,0.8242,0.714,0.245,"angiogenin-PRI complex"),
c("GO:1990909","Wnt signalosome",0.002,0.5787,0.792,0.247,"angiogenin-PRI complex"),
c("GO:0071141","SMAD protein complex",0.002,0.5997,0.746,0.248,"angiogenin-PRI complex"),
c("GO:0031431","Dbf4-dependent protein kinase complex",0.003,0.7190,0.743,0.252,"angiogenin-PRI complex"),
c("GO:0033186","CAF-1 complex",0.003,0.6381,0.787,0.253,"angiogenin-PRI complex"),
c("GO:0031251","PAN complex",0.011,0.8454,0.686,0.269,"angiogenin-PRI complex"),
c("GO:0031209","SCAR complex",0.005,0.7261,0.698,0.270,"angiogenin-PRI complex"),
c("GO:0030991","intraciliary transport particle A",0.005,0.7726,0.779,0.271,"angiogenin-PRI complex"),
c("GO:0017102","methionyl glutamyl tRNA synthetase complex",0.005,0.5485,0.697,0.271,"angiogenin-PRI complex"),
c("GO:0017101","aminoacyl-tRNA synthetase multienzyme complex",0.006,0.5580,0.733,0.272,"angiogenin-PRI complex"),
c("GO:0030015","CCR4-NOT core complex",0.009,0.5646,0.727,0.279,"angiogenin-PRI complex"),
c("GO:0000974","Prp19 complex",0.017,0.8421,0.769,0.288,"angiogenin-PRI complex"),
c("GO:0005956","protein kinase CK2 complex",0.019,0.8387,0.717,0.297,"angiogenin-PRI complex"),
c("GO:0005958","DNA-dependent protein kinase-DNA ligase 4 complex",0.001,0.6457,0.639,0.316,"angiogenin-PRI complex"),
c("GO:0042555","MCM complex",0.057,0.8021,0.753,0.320,"angiogenin-PRI complex"),
c("GO:0032807","DNA ligase IV complex",0.002,0.6415,0.633,0.322,"angiogenin-PRI complex"),
c("GO:0030014","CCR4-NOT complex",0.029,0.6295,0.710,0.329,"angiogenin-PRI complex"),
c("GO:0033588","Elongator holoenzyme complex",0.030,0.6551,0.709,0.330,"angiogenin-PRI complex"),
c("GO:0048476","Holliday junction resolvase complex",0.054,0.5506,0.700,0.343,"angiogenin-PRI complex"),
c("GO:0016272","prefoldin complex",0.056,0.5881,0.753,0.344,"angiogenin-PRI complex"),
c("GO:1990904","ribonucleoprotein complex",5.291,0.5974,0.737,0.348,"angiogenin-PRI complex"),
c("GO:0005581","collagen trimer",0.071,0.7959,0.749,0.349,"angiogenin-PRI complex"),
c("GO:0030686","90S preribosome",0.059,0.8188,0.727,0.363,"angiogenin-PRI complex"),
c("GO:0005852","eukaryotic translation initiation factor 3 complex",0.117,0.7812,0.642,0.367,"angiogenin-PRI complex"),
c("GO:0000932","P-body",0.055,0.7331,0.630,0.373,"angiogenin-PRI complex"),
c("GO:0005732","small nucleolar ribonucleoprotein complex",0.072,0.7999,0.730,0.380,"angiogenin-PRI complex"),
c("GO:0070701","mucus layer",0.004,0.8606,0.974,0.382,"angiogenin-PRI complex"),
c("GO:0033290","eukaryotic 48S preinitiation complex",0.089,0.7894,0.678,0.391,"angiogenin-PRI complex"),
c("GO:0005856","cytoskeleton",1.542,0.6904,0.671,0.399,"angiogenin-PRI complex"),
c("GO:0005667","transcription factor complex",0.288,0.7281,0.668,0.408,"angiogenin-PRI complex"),
c("GO:0005604","basement membrane",0.041,0.8384,0.965,0.479,"angiogenin-PRI complex"),
c("GO:0032991","macromolecular complex",14.008,0.5711,0.995,0.000,"macromolecular complex"),
c("GO:0044162","host cell cytoplasmic vesicle membrane",0.000,0.8202,0.979,0.000,"host cell cytoplasmic vesicle membrane"),
c("GO:0045202","synapse",0.299,0.7350,0.994,0.000,"synapse"),
c("GO:0098978","glutamatergic synapse",0.000,0.6564,0.976,0.000,"glutamatergic synapse"),
c("GO:0001411","hyphal tip",0.001,0.7627,0.943,0.022,"hyphal tip"),
c("GO:0045177","apical part of cell",0.085,0.7205,0.927,0.032,"apical part of cell"),
c("GO:0019898","extrinsic component of membrane",0.249,0.6349,0.981,0.035,"extrinsic component of membrane"),
c("GO:0030496","midbody",0.040,0.5548,0.930,0.041,"midbody"),
c("GO:0005933","cellular bud",0.047,0.6792,0.929,0.042,"cellular bud"),
c("GO:0009986","cell surface",0.241,0.7114,0.922,0.047,"cell surface"),
c("GO:0031252","cell leading edge",0.086,0.5584,0.927,0.047,"cell leading edge"),
c("GO:0060293","germ plasm",0.009,0.8495,0.860,0.078,"germ plasm"),
c("GO:0060171","stereocilium membrane",0.000,0.8758,0.653,0.087,"stereocilium membrane"),
c("GO:0001673","male germ cell nucleus",0.004,0.7329,0.771,0.110,"stereocilium membrane"),
c("GO:0002177","manchette",0.001,0.8636,0.706,0.180,"stereocilium membrane"),
c("GO:0001533","cornified envelope",0.007,0.7839,0.896,0.183,"stereocilium membrane"),
c("GO:0005796","Golgi lumen",0.003,0.8634,0.660,0.202,"stereocilium membrane"),
c("GO:0031430","M band",0.007,0.8549,0.677,0.223,"stereocilium membrane"),
c("GO:0012511","monolayer-surrounded lipid storage body",0.005,0.8514,0.768,0.240,"stereocilium membrane"),
c("GO:0005938","cell cortex",0.252,0.7600,0.725,0.245,"stereocilium membrane"),
c("GO:0005811","lipid particle",0.055,0.8074,0.736,0.273,"stereocilium membrane"),
c("GO:0048471","perinuclear region of cytoplasm",0.135,0.7147,0.786,0.287,"stereocilium membrane"),
c("GO:0005777","peroxisome",0.215,0.5762,0.699,0.298,"stereocilium membrane"),
c("GO:0038039","G-protein coupled receptor heterodimeric complex",0.001,0.8647,0.762,0.299,"stereocilium membrane"),
c("GO:1990851","Wnt-Frizzled-LRP5/6 complex",0.001,0.5910,0.723,0.309,"stereocilium membrane"),
c("GO:0005773","vacuole",0.455,0.7047,0.690,0.317,"stereocilium membrane"),
c("GO:0005618","cell wall",0.294,0.7371,0.870,0.323,"stereocilium membrane"),
c("GO:0034663","endoplasmic reticulum chaperone complex",0.003,0.5468,0.622,0.329,"stereocilium membrane"),
c("GO:0044611","nuclear pore inner ring",0.003,0.8625,0.588,0.332,"stereocilium membrane"),
c("GO:0071595","Nem1-Spo7 phosphatase complex",0.003,0.8546,0.706,0.333,"stereocilium membrane"),
c("GO:0001891","phagocytic cup",0.005,0.5583,0.871,0.335,"stereocilium membrane"),
c("GO:0000814","ESCRT II complex",0.007,0.8343,0.568,0.347,"stereocilium membrane"),
c("GO:1905360","GTPase complex",0.046,0.8254,0.766,0.349,"stereocilium membrane"),
c("GO:0005662","DNA replication factor A complex",0.009,0.8505,0.564,0.353,"stereocilium membrane"),
c("GO:0030312","external encapsulating structure",0.922,0.5932,0.862,0.363,"stereocilium membrane"),
c("GO:0016589","NURF complex",0.011,0.8447,0.596,0.364,"stereocilium membrane"),
c("GO:0035145","exon-exon junction complex",0.010,0.8417,0.602,0.367,"stereocilium membrane"),
c("GO:0005760","gamma DNA polymerase complex",0.008,0.8492,0.586,0.372,"stereocilium membrane"),
c("GO:1902560","GMP reductase complex",0.009,0.8136,0.753,0.373,"stereocilium membrane"),
c("GO:0035101","FACT complex",0.005,0.8442,0.593,0.383,"stereocilium membrane"),
c("GO:0000172","ribonuclease MRP complex",0.014,0.6583,0.717,0.383,"stereocilium membrane"),
c("GO:0071011","precatalytic spliceosome",0.027,0.8429,0.594,0.387,"stereocilium membrane"),
c("GO:0000347","THO complex",0.013,0.8317,0.597,0.392,"stereocilium membrane"),
c("GO:0005969","serine-pyruvate aminotransferase complex",0.000,0.5528,0.730,0.393,"stereocilium membrane"),
c("GO:0005829","cytosol",2.553,0.6879,0.736,0.398,"stereocilium membrane"),
c("GO:0031265","CD95 death-inducing signaling complex",0.001,0.5588,0.719,0.400,"stereocilium membrane"),
c("GO:0002102","podosome",0.006,0.6815,0.604,0.409,"stereocilium membrane"),
c("GO:0008180","COP9 signalosome",0.031,0.8020,0.579,0.412,"stereocilium membrane"),
c("GO:0005890","sodium:potassium-exchanging ATPase complex",0.011,0.8448,0.698,0.416,"stereocilium membrane"),
c("GO:0000176","nuclear exosome (RNase complex)",0.023,0.8392,0.579,0.417,"stereocilium membrane"),
c("GO:0005655","nucleolar ribonuclease P complex",0.011,0.6659,0.578,0.422,"stereocilium membrane"),
c("GO:0010445","nuclear dicing body",0.001,0.6536,0.696,0.428,"stereocilium membrane"),
c("GO:0033179","proton-transporting V-type ATPase, V0 domain",0.081,0.7893,0.728,0.432,"stereocilium membrane"),
c("GO:0016363","nuclear matrix",0.019,0.6040,0.655,0.436,"stereocilium membrane"),
c("GO:0097225","sperm midpiece",0.004,0.8552,0.685,0.437,"stereocilium membrane"),
c("GO:0009897","external side of plasma membrane",0.064,0.8063,0.843,0.441,"stereocilium membrane"),
c("GO:1990604","IRE1-TRAF2-ASK1 complex",0.001,0.5757,0.626,0.445,"stereocilium membrane"),
c("GO:0031262","Ndc80 complex",0.003,0.8435,0.625,0.452,"stereocilium membrane"),
c("GO:0030897","HOPS complex",0.016,0.7673,0.751,0.455,"stereocilium membrane"),
c("GO:0031380","nuclear RNA-directed RNA polymerase complex",0.000,0.5589,0.655,0.458,"stereocilium membrane"),
c("GO:0033093","Weibel-Palade body",0.001,0.6324,0.729,0.463,"stereocilium membrane"),
c("GO:0005868","cytoplasmic dynein complex",0.020,0.8305,0.557,0.472,"stereocilium membrane"),
c("GO:0034098","VCP-NPL4-UFD1 AAA ATPase complex",0.005,0.8492,0.601,0.475,"stereocilium membrane"),
c("GO:0080008","Cul4-RING E3 ubiquitin ligase complex",0.015,0.8377,0.713,0.476,"stereocilium membrane"),
c("GO:0005681","spliceosomal complex",0.250,0.7620,0.545,0.478,"stereocilium membrane"),
c("GO:0005739","mitochondrion",2.156,0.6120,0.653,0.481,"stereocilium membrane"),
c("GO:0009707","chloroplast outer membrane",0.006,0.5962,0.666,0.484,"stereocilium membrane"),
c("GO:0000421","autophagosome membrane",0.006,0.8089,0.674,0.485,"stereocilium membrane"),
c("GO:0031021","interphase microtubule organizing center",0.003,0.7264,0.693,0.490,"stereocilium membrane"),
c("GO:0046658","anchored component of plasma membrane",0.030,0.8161,0.854,0.496,"stereocilium membrane"),
c("GO:0015935","small ribosomal subunit",0.551,0.7086,0.546,0.498,"stereocilium membrane"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
