

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0005576","extracellular region",2.375,0.6690,0.994,0.000,"extracellular region"),
c("GO:0005623","cell",53.553,0.6627,0.997,0.000,"cell"),
c("GO:0005780","extrinsic component of intraperoxisomal membrane",0.003,0.8592,0.670,0.000,"extrinsic component of intraperoxisomal membrane"),
c("GO:0045169","fusome",0.002,0.4225,0.823,0.171,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000407","pre-autophagosomal structure",0.033,0.8186,0.795,0.196,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990072","TRAPPIII protein complex",0.004,0.8522,0.641,0.215,"extrinsic component of intraperoxisomal membrane"),
c("GO:0070062","extracellular exosome",0.682,0.8323,0.668,0.220,"extrinsic component of intraperoxisomal membrane"),
c("GO:0097057","TRAF2-GSTP1 complex",0.001,0.5790,0.883,0.232,"extrinsic component of intraperoxisomal membrane"),
c("GO:0033290","eukaryotic 48S preinitiation complex",0.089,0.7674,0.710,0.240,"extrinsic component of intraperoxisomal membrane"),
c("GO:0035861","site of double-strand break",0.032,0.8339,0.690,0.243,"extrinsic component of intraperoxisomal membrane"),
c("GO:0043235","receptor complex",0.115,0.7284,0.874,0.245,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990909","Wnt signalosome",0.002,0.5581,0.876,0.246,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005793","endoplasmic reticulum-Golgi intermediate compartment",0.026,0.5453,0.741,0.250,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990130","Iml1 complex",0.003,0.6035,0.869,0.252,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005801","cis-Golgi network",0.038,0.5340,0.758,0.258,"extrinsic component of intraperoxisomal membrane"),
c("GO:0048471","perinuclear region of cytoplasm",0.135,0.6120,0.776,0.265,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000445","THO complex part of transcription export complex",0.011,0.8470,0.656,0.268,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030877","beta-catenin destruction complex",0.004,0.5446,0.744,0.268,"extrinsic component of intraperoxisomal membrane"),
c("GO:0032045","guanyl-nucleotide exchange factor complex",0.009,0.5254,0.794,0.279,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030018","Z disc",0.026,0.6178,0.671,0.286,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031083","BLOC-1 complex",0.017,0.8442,0.724,0.289,"extrinsic component of intraperoxisomal membrane"),
c("GO:0042579","microbody",0.215,0.7684,0.704,0.297,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005938","cell cortex",0.252,0.7604,0.698,0.298,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031932","TORC2 complex",0.025,0.8262,0.781,0.303,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031984","organelle subcompartment",0.269,0.4911,0.669,0.315,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990124","messenger ribonucleoprotein complex",0.002,0.4475,0.823,0.315,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005773","vacuole",0.455,0.7035,0.688,0.319,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005618","cell wall",0.294,0.6472,0.858,0.323,"extrinsic component of intraperoxisomal membrane"),
c("GO:0009507","chloroplast",0.351,0.6581,0.694,0.327,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005581","collagen trimer",0.071,0.7921,0.849,0.331,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030014","CCR4-NOT complex",0.029,0.4474,0.780,0.334,"extrinsic component of intraperoxisomal membrane"),
c("GO:1902494","catalytic complex",3.734,0.4793,0.837,0.336,"extrinsic component of intraperoxisomal membrane"),
c("GO:0043614","multi-eIF complex",0.012,0.4353,0.745,0.347,"extrinsic component of intraperoxisomal membrane"),
c("GO:0035102","PRC1 complex",0.004,0.8386,0.651,0.348,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031982","vesicle",1.362,0.6835,0.733,0.357,"extrinsic component of intraperoxisomal membrane"),
c("GO:0044815","DNA packaging complex",0.216,0.4448,0.869,0.359,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005852","eukaryotic translation initiation factor 3 complex",0.117,0.7860,0.691,0.367,"extrinsic component of intraperoxisomal membrane"),
c("GO:0043228","non-membrane-bounded organelle",8.408,0.4679,0.735,0.367,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005788","endoplasmic reticulum lumen",0.027,0.7298,0.637,0.379,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016514","SWI/SNF complex",0.020,0.8115,0.638,0.380,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005856","cytoskeleton",1.542,0.6909,0.677,0.382,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005641","nuclear envelope lumen",0.004,0.6077,0.670,0.383,"extrinsic component of intraperoxisomal membrane"),
c("GO:0032993","protein-DNA complex",0.418,0.4659,0.863,0.386,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030687","preribosome, large subunit precursor",0.067,0.6474,0.784,0.388,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031379","RNA-directed RNA polymerase complex",0.001,0.5599,0.811,0.394,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005829","cytosol",2.553,0.6878,0.721,0.398,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005811","lipid particle",0.055,0.5550,0.746,0.399,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005667","transcription factor complex",0.288,0.7489,0.745,0.408,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016363","nuclear matrix",0.019,0.6355,0.691,0.417,"extrinsic component of intraperoxisomal membrane"),
c("GO:0036464","cytoplasmic ribonucleoprotein granule",0.127,0.5448,0.636,0.430,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031090","organelle membrane",2.003,0.4311,0.650,0.435,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005763","mitochondrial small ribosomal subunit",0.040,0.6532,0.604,0.436,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031523","Myb complex",0.001,0.4867,0.689,0.464,"extrinsic component of intraperoxisomal membrane"),
c("GO:0043083","synaptic cleft",0.003,0.5827,0.931,0.470,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005886","plasma membrane",10.510,0.5575,0.810,0.472,"extrinsic component of intraperoxisomal membrane"),
c("GO:0098844","postsynaptic endocytic zone membrane",0.000,0.4595,0.835,0.475,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000124","SAGA complex",0.030,0.8033,0.601,0.476,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005681","spliceosomal complex",0.250,0.6794,0.592,0.477,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005739","mitochondrion",2.156,0.6142,0.647,0.481,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000221","vacuolar proton-transporting V-type ATPase, V1 domain",0.015,0.8455,0.585,0.488,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990604","IRE1-TRAF2-ASK1 complex",0.001,0.5645,0.657,0.489,"extrinsic component of intraperoxisomal membrane"),
c("GO:0098982","GABA-ergic synapse",0.000,0.4677,0.947,0.500,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016529","sarcoplasmic reticulum",0.017,0.5632,0.701,0.504,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005952","cAMP-dependent protein kinase complex",0.014,0.4560,0.779,0.512,"extrinsic component of intraperoxisomal membrane"),
c("GO:0071339","MLL1 complex",0.008,0.7894,0.642,0.533,"extrinsic component of intraperoxisomal membrane"),
c("GO:0044352","pinosome",0.002,0.4238,0.699,0.535,"extrinsic component of intraperoxisomal membrane"),
c("GO:0098796","membrane protein complex",2.473,0.6197,0.791,0.538,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005901","caveola",0.020,0.8396,0.755,0.541,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990904","ribonucleoprotein complex",5.291,0.5678,0.833,0.543,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031045","dense core granule",0.003,0.8158,0.688,0.545,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005634","nucleus",8.965,0.6104,0.632,0.547,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005694","chromosome",1.505,0.6788,0.678,0.557,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000794","condensed nuclear chromosome",0.114,0.7924,0.629,0.558,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000808","origin recognition complex",0.036,0.4101,0.631,0.561,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005818","aster",0.005,0.5333,0.692,0.571,"extrinsic component of intraperoxisomal membrane"),
c("GO:0042600","chorion",0.004,0.4278,0.890,0.582,"extrinsic component of intraperoxisomal membrane"),
c("GO:0071797","LUBAC complex",0.003,0.5164,0.796,0.588,"extrinsic component of intraperoxisomal membrane"),
c("GO:0001739","sex chromatin",0.001,0.5780,0.671,0.591,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005802","trans-Golgi network",0.096,0.7532,0.625,0.596,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031594","neuromuscular junction",0.017,0.4939,0.938,0.602,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000781","chromosome, telomeric region",0.112,0.7906,0.664,0.609,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000151","ubiquitin ligase complex",0.232,0.5012,0.741,0.614,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005783","endoplasmic reticulum",1.332,0.7104,0.605,0.616,"extrinsic component of intraperoxisomal membrane"),
c("GO:0042470","melanosome",0.016,0.4973,0.688,0.616,"extrinsic component of intraperoxisomal membrane"),
c("GO:0098839","postsynaptic density membrane",0.002,0.4593,0.654,0.617,"extrinsic component of intraperoxisomal membrane"),
c("GO:0043229","intracellular organelle",19.917,0.4798,0.660,0.618,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016607","nuclear speck",0.091,0.8018,0.657,0.619,"extrinsic component of intraperoxisomal membrane"),
c("GO:1990075","periciliary membrane compartment",0.002,0.4469,0.842,0.621,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005741","mitochondrial outer membrane",0.149,0.7784,0.588,0.623,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005776","autophagosome",0.024,0.5532,0.714,0.627,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000421","autophagosome membrane",0.006,0.6944,0.656,0.629,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005840","ribosome",4.198,0.5696,0.536,0.635,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031527","filopodium membrane",0.003,0.6620,0.757,0.640,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005669","transcription factor TFIID complex",0.052,0.7191,0.587,0.642,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031902","late endosome membrane",0.027,0.7666,0.582,0.642,"extrinsic component of intraperoxisomal membrane"),
c("GO:0045335","phagocytic vesicle",0.028,0.6917,0.678,0.644,"extrinsic component of intraperoxisomal membrane"),
c("GO:0033176","proton-transporting V-type ATPase complex",0.146,0.4824,0.818,0.650,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016327","apicolateral plasma membrane",0.005,0.7385,0.835,0.651,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031088","platelet dense granule membrane",0.001,0.5820,0.642,0.656,"extrinsic component of intraperoxisomal membrane"),
c("GO:0034708","methyltransferase complex",0.080,0.4900,0.758,0.659,"extrinsic component of intraperoxisomal membrane"),
c("GO:0097208","alveolar lamellar body",0.001,0.4609,0.698,0.666,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031463","Cul3-RING ubiquitin ligase complex",0.034,0.7558,0.768,0.666,"extrinsic component of intraperoxisomal membrane"),
c("GO:0009925","basal plasma membrane",0.007,0.5804,0.831,0.667,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005654","nucleoplasm",1.372,0.6955,0.591,0.667,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005604","basement membrane",0.041,0.5953,0.981,0.670,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031967","organelle envelope",1.258,0.4211,0.614,0.675,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031234","extrinsic component of cytoplasmic side of plasma membrane",0.068,0.6617,0.757,0.676,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031305","integral component of mitochondrial inner membrane",0.053,0.7229,0.628,0.679,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000839","Hrd1p ubiquitin ligase ERAD-L complex",0.005,0.5989,0.623,0.680,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000786","nucleosome",0.191,0.7456,0.606,0.681,"extrinsic component of intraperoxisomal membrane"),
c("GO:0015935","small ribosomal subunit",0.551,0.4448,0.571,0.684,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030139","endocytic vesicle",0.064,0.4912,0.663,0.687,"extrinsic component of intraperoxisomal membrane"),
c("GO:0031965","nuclear membrane",0.100,0.5588,0.593,0.691,"extrinsic component of intraperoxisomal membrane"),
c("GO:0030478","actin cap",0.001,0.4458,0.658,0.691,"extrinsic component of intraperoxisomal membrane"),
c("GO:0000791","euchromatin",0.011,0.5521,0.667,0.694,"extrinsic component of intraperoxisomal membrane"),
c("GO:0016592","mediator complex",0.155,0.7729,0.584,0.694,"extrinsic component of intraperoxisomal membrane"),
c("GO:0005918","septate junction",0.002,0.8641,0.970,0.000,"septate junction"),
c("GO:0097025","MPP7-DLG1-LIN7 complex",0.001,0.8163,0.751,0.484,"septate junction"),
c("GO:0005911","cell-cell junction",0.222,0.7257,0.964,0.639,"septate junction"),
c("GO:0016020","membrane",61.592,0.4229,0.998,0.000,"membrane"),
c("GO:0016533","cyclin-dependent protein kinase 5 holoenzyme complex",0.003,0.8565,0.898,0.000,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0005890","sodium:potassium-exchanging ATPase complex",0.011,0.8461,0.749,0.172,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0001533","cornified envelope",0.007,0.7051,0.884,0.215,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0042383","sarcolemma",0.024,0.6529,0.876,0.231,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0071133","alpha9-beta1 integrin-ADAM8 complex",0.001,0.5234,0.778,0.343,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0005868","cytoplasmic dynein complex",0.020,0.8258,0.612,0.358,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0001891","phagocytic cup",0.005,0.6326,0.852,0.381,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:1905360","GTPase complex",0.046,0.6099,0.857,0.391,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0030315","T-tubule",0.008,0.5243,0.849,0.391,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0001772","immunological synapse",0.010,0.5785,0.847,0.395,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0016328","lateral plasma membrane",0.014,0.4485,0.844,0.403,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:1904949","ATPase complex",0.680,0.5029,0.829,0.499,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0008305","integrin complex",0.031,0.7726,0.719,0.506,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0030117","membrane coat",0.264,0.7457,0.662,0.515,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0030904","retromer complex",0.032,0.5751,0.722,0.516,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0005891","voltage-gated calcium channel complex",0.032,0.7898,0.757,0.548,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0016459","myosin complex",0.128,0.7698,0.584,0.565,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:1905368","peptidase complex",0.452,0.4831,0.834,0.609,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0002102","podosome",0.006,0.5225,0.650,0.672,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0005887","integral component of plasma membrane",1.211,0.6644,0.789,0.687,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0098590","plasma membrane region",0.239,0.4776,0.814,0.696,"cyclin-dependent protein kinase 5 holoenzyme complex"),
c("GO:0030054","cell junction",0.445,0.6309,0.994,0.000,"cell junction"),
c("GO:0032991","macromolecular complex",14.008,0.5704,0.995,0.000,"macromolecular complex"),
c("GO:0042025","host cell nucleus",0.027,0.4943,0.990,0.000,"host cell nucleus"),
c("GO:0045202","synapse",0.299,0.7463,0.994,0.000,"synapse"),
c("GO:0098978","glutamatergic synapse",0.000,0.5505,0.953,0.000,"glutamatergic synapse"),
c("GO:0099080","supramolecular complex",0.540,0.4364,0.994,0.000,"supramolecular complex"),
c("GO:0048475","coated membrane",0.264,0.7485,0.979,0.023,"coated membrane"),
c("GO:0019898","extrinsic component of membrane",0.249,0.6828,0.977,0.031,"extrinsic component of membrane"),
c("GO:0030426","growth cone",0.019,0.8451,0.786,0.032,"growth cone"),
c("GO:0035230","cytoneme",0.000,0.4023,0.872,0.428,"growth cone"),
c("GO:0031143","pseudopodium",0.005,0.5947,0.856,0.486,"growth cone"),
c("GO:0099056","integral component of presynaptic membrane",0.000,0.5777,0.792,0.497,"growth cone"),
c("GO:0030027","lamellipodium",0.040,0.8301,0.835,0.550,"growth cone"),
c("GO:0044327","dendritic spine head",0.000,0.4579,0.805,0.586,"growth cone"),
c("GO:0036064","ciliary basal body",0.035,0.8230,0.596,0.600,"growth cone"),
c("GO:0032809","neuronal cell body membrane",0.004,0.5878,0.786,0.609,"growth cone"),
c("GO:0001917","photoreceptor inner segment",0.008,0.5327,0.860,0.639,"growth cone"),
c("GO:0005929","cilium",0.221,0.6527,0.695,0.647,"growth cone"),
c("GO:0000935","barrier septum",0.007,0.5146,0.935,0.034,"barrier septum"),
c("GO:0045178","basal part of cell",0.013,0.4230,0.933,0.035,"basal part of cell"),
c("GO:0030428","cell septum",0.014,0.5512,0.933,0.035,"cell septum"),
c("GO:0019867","outer membrane",1.018,0.6231,0.978,0.035,"outer membrane"),
c("GO:0031225","anchored component of membrane",0.078,0.6526,0.978,0.036,"anchored component of membrane"),
c("GO:0098552","side of membrane",0.214,0.4465,0.977,0.039,"side of membrane"),
c("GO:0045177","apical part of cell",0.085,0.8047,0.925,0.039,"apical part of cell"),
c("GO:0005903","brush border",0.023,0.5676,0.917,0.040,"brush border"),
c("GO:0098805","whole membrane",0.888,0.5680,0.978,0.040,"whole membrane"),
c("GO:0030496","midbody",0.040,0.4891,0.929,0.041,"midbody"),
c("GO:0009986","cell surface",0.241,0.7530,0.920,0.047,"cell surface"),
c("GO:0031252","cell leading edge",0.086,0.5567,0.925,0.047,"cell leading edge"),
c("GO:0044297","cell body",0.087,0.4576,0.925,0.047,"cell body"),
c("GO:0012505","endomembrane system",2.811,0.6718,0.903,0.064,"endomembrane system"),
c("GO:0016235","aggresome",0.010,0.5597,0.887,0.068,"aggresome"),
c("GO:0005737","cytoplasm",26.017,0.5158,0.791,0.126,"aggresome"),
c("GO:0071944","cell periphery",11.583,0.4177,0.890,0.176,"aggresome"),
c("GO:0016021","integral component of membrane",55.868,0.4341,0.967,0.072,"integral component of membrane"),
c("GO:0042995","cell projection",1.050,0.3994,0.911,0.076,"cell projection"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
