

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0005576","extracellular region",2.375,0.6670,0.983,0.000,"extracellular region"),
c("GO:0005615","extracellular space",0.538,0.7339,0.942,0.000,"extracellular space"),
c("GO:0005623","cell",53.553,0.6561,0.992,0.000,"cell"),
c("GO:0005925","focal adhesion",0.109,0.5361,0.935,0.000,"focal adhesion"),
c("GO:0016020","membrane",61.592,0.3835,0.993,0.000,"membrane"),
c("GO:0030054","cell junction",0.445,0.7453,0.983,0.000,"cell junction"),
c("GO:0031594","neuromuscular junction",0.017,0.4998,0.970,0.000,"neuromuscular junction"),
c("GO:0032991","macromolecular complex",14.008,0.5148,0.985,0.000,"macromolecular complex"),
c("GO:0043235","receptor complex",0.115,0.5038,0.910,0.000,"receptor complex"),
c("GO:0045177","apical part of cell",0.085,0.8095,0.912,0.000,"apical part of cell"),
c("GO:0045202","synapse",0.299,0.5152,0.983,0.000,"synapse"),
c("GO:0098805","whole membrane",0.888,0.4564,0.970,0.000,"whole membrane"),
c("GO:0045121","membrane raft",0.076,0.4846,0.939,0.031,"membrane raft"),
c("GO:0005628","prospore membrane",0.007,0.4624,0.921,0.037,"prospore membrane"),
c("GO:0030027","lamellipodium",0.040,0.4050,0.848,0.041,"lamellipodium"),
c("GO:0016324","apical plasma membrane",0.061,0.6981,0.802,0.043,"apical plasma membrane"),
c("GO:0009279","cell outer membrane",0.624,0.6693,0.804,0.305,"apical plasma membrane"),
c("GO:0043020","NADPH oxidase complex",0.003,0.4501,0.796,0.406,"apical plasma membrane"),
c("GO:0016328","lateral plasma membrane",0.014,0.4466,0.827,0.447,"apical plasma membrane"),
c("GO:0035866","alphav-beta3 integrin-PKCalpha complex",0.019,0.4140,0.766,0.456,"apical plasma membrane"),
c("GO:0005641","nuclear envelope lumen",0.004,0.5999,0.695,0.487,"apical plasma membrane"),
c("GO:0043025","neuronal cell body",0.073,0.5757,0.808,0.043,"neuronal cell body"),
c("GO:0005795","Golgi stack",0.078,0.7989,0.636,0.043,"Golgi stack"),
c("GO:0005737","cytoplasm",26.017,0.5138,0.770,0.156,"Golgi stack"),
c("GO:0005764","lysosome",0.149,0.7044,0.655,0.264,"Golgi stack"),
c("GO:0048471","perinuclear region of cytoplasm",0.135,0.5074,0.763,0.275,"Golgi stack"),
c("GO:0030018","Z disc",0.026,0.4096,0.683,0.277,"Golgi stack"),
c("GO:0005685","U1 snRNP",0.042,0.4266,0.666,0.295,"Golgi stack"),
c("GO:0031982","vesicle",1.362,0.4035,0.731,0.306,"Golgi stack"),
c("GO:0016459","myosin complex",0.128,0.7662,0.604,0.318,"Golgi stack"),
c("GO:0071541","eukaryotic translation initiation factor 3 complex, eIF3m",0.011,0.3584,0.751,0.326,"Golgi stack"),
c("GO:0005811","lipid particle",0.055,0.3425,0.738,0.329,"Golgi stack"),
c("GO:0005829","cytosol",2.553,0.6872,0.704,0.355,"Golgi stack"),
c("GO:0000786","nucleosome",0.191,0.7484,0.642,0.361,"Golgi stack"),
c("GO:0031984","organelle subcompartment",0.269,0.5046,0.674,0.361,"Golgi stack"),
c("GO:1990904","ribonucleoprotein complex",5.291,0.3765,0.883,0.367,"Golgi stack"),
c("GO:0005777","peroxisome",0.215,0.3407,0.691,0.368,"Golgi stack"),
c("GO:0005581","collagen trimer",0.071,0.6863,0.896,0.369,"Golgi stack"),
c("GO:0005938","cell cortex",0.252,0.6561,0.690,0.374,"Golgi stack"),
c("GO:0033290","eukaryotic 48S preinitiation complex",0.089,0.3524,0.717,0.376,"Golgi stack"),
c("GO:0005852","eukaryotic translation initiation factor 3 complex",0.117,0.3743,0.713,0.383,"Golgi stack"),
c("GO:0005773","vacuole",0.455,0.4778,0.674,0.398,"Golgi stack"),
c("GO:0005771","multivesicular body",0.009,0.5858,0.674,0.421,"Golgi stack"),
c("GO:0000502","proteasome complex",0.389,0.3834,0.769,0.421,"Golgi stack"),
c("GO:0005856","cytoskeleton",1.542,0.6903,0.666,0.447,"Golgi stack"),
c("GO:0005667","transcription factor complex",0.288,0.3386,0.777,0.451,"Golgi stack"),
c("GO:0035974","meiotic spindle pole body",0.001,0.4269,0.727,0.480,"Golgi stack"),
c("GO:0005739","mitochondrion",2.156,0.3909,0.630,0.481,"Golgi stack"),
c("GO:0009986","cell surface",0.241,0.5212,0.906,0.047,"cell surface"),
c("GO:0031252","cell leading edge",0.086,0.4592,0.912,0.047,"cell leading edge"),
c("GO:0044297","cell body",0.087,0.4154,0.912,0.047,"cell body"),
c("GO:0012505","endomembrane system",2.811,0.4289,0.887,0.064,"endomembrane system"),
c("GO:0016021","integral component of membrane",55.868,0.4341,0.967,0.070,"integral component of membrane"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
