

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0000981","RNA polymerase II transcription factor activity, sequence-specific DNA binding",0.640,0.7324,0.991,0.000,"RNA polymerase II transcription factor activity, sequence-specific DNA binding"),
c("GO:0001228","transcriptional activator activity, RNA polymerase II transcription regulatory region sequence-specific binding",0.079,0.8075,0.991,0.497,"RNA polymerase II transcription factor activity, sequence-specific DNA binding"),
c("GO:0001616","growth hormone secretagogue receptor activity",0.000,0.8614,0.931,0.000,"growth hormone secretagogue receptor activity"),
c("GO:0038006","netrin receptor activity involved in chemoattraction",0.000,0.7829,0.940,0.313,"growth hormone secretagogue receptor activity"),
c("GO:0005044","scavenger receptor activity",0.041,0.8175,0.934,0.339,"growth hormone secretagogue receptor activity"),
c("GO:0071936","coreceptor activity involved in Wnt signaling pathway",0.002,0.7622,0.936,0.376,"growth hormone secretagogue receptor activity"),
c("GO:0005221","intracellular cyclic nucleotide activated cation channel activity",0.003,0.8546,0.870,0.388,"growth hormone secretagogue receptor activity"),
c("GO:0005034","osmosensor activity",0.001,0.7433,0.928,0.409,"growth hormone secretagogue receptor activity"),
c("GO:0031992","energy transducer activity",0.012,0.7456,0.938,0.418,"growth hormone secretagogue receptor activity"),
c("GO:0016493","C-C chemokine receptor activity",0.004,0.8519,0.919,0.440,"growth hormone secretagogue receptor activity"),
c("GO:0038024","cargo receptor activity",0.046,0.6994,0.933,0.454,"growth hormone secretagogue receptor activity"),
c("GO:0005003","ephrin receptor activity",0.008,0.8455,0.836,0.468,"growth hormone secretagogue receptor activity"),
c("GO:0003713","transcription coactivator activity",0.090,0.7981,0.985,0.000,"transcription coactivator activity"),
c("GO:0004720","protein-lysine 6-oxidase activity",0.001,0.8696,0.962,0.000,"protein-lysine 6-oxidase activity"),
c("GO:0033781","cholesterol 24-hydroxylase activity",0.000,0.8171,0.958,0.145,"protein-lysine 6-oxidase activity"),
c("GO:0050664","oxidoreductase activity, acting on NAD(P)H, oxygen as acceptor",0.011,0.8435,0.951,0.172,"protein-lysine 6-oxidase activity"),
c("GO:0009013","succinate-semialdehyde dehydrogenase [NAD(P)+] activity",0.020,0.8113,0.953,0.204,"protein-lysine 6-oxidase activity"),
c("GO:0051903","S-(hydroxymethyl)glutathione dehydrogenase activity",0.016,0.8026,0.951,0.208,"protein-lysine 6-oxidase activity"),
c("GO:0015035","protein disulfide oxidoreductase activity",0.305,0.7332,0.948,0.251,"protein-lysine 6-oxidase activity"),
c("GO:0004601","peroxidase activity",0.377,0.7190,0.947,0.316,"protein-lysine 6-oxidase activity"),
c("GO:0016705","oxidoreductase activity, acting on paired donors, with incorporation or reduction of molecular oxygen",1.177,0.6892,0.943,0.358,"protein-lysine 6-oxidase activity"),
c("GO:0004497","monooxygenase activity",0.947,0.6808,0.944,0.394,"protein-lysine 6-oxidase activity"),
c("GO:0016706","oxidoreductase activity, acting on paired donors, with incorporation or reduction of molecular oxygen, 2-oxoglutarate as one donor, and incorporation of one atom each of oxygen into both donors",0.052,0.7958,0.948,0.427,"protein-lysine 6-oxidase activity"),
c("GO:0016174","NAD(P)H oxidase activity",0.003,0.7098,0.954,0.493,"protein-lysine 6-oxidase activity"),
c("GO:0008307","structural constituent of muscle",0.006,0.8569,0.984,0.000,"structural constituent of muscle"),
c("GO:0005201","extracellular matrix structural constituent",0.028,0.8263,0.983,0.369,"structural constituent of muscle"),
c("GO:0005199","structural constituent of cell wall",0.017,0.7835,0.983,0.393,"structural constituent of muscle"),
c("GO:0017056","structural constituent of nuclear pore",0.025,0.7993,0.983,0.402,"structural constituent of muscle"),
c("GO:0042302","structural constituent of cuticle",0.063,0.8065,0.982,0.426,"structural constituent of muscle"),
c("GO:0005200","structural constituent of cytoskeleton",0.079,0.7774,0.982,0.456,"structural constituent of muscle"),
c("GO:0017112","Rab guanyl-nucleotide exchange factor activity",0.012,0.8430,0.962,0.000,"Rab guanyl-nucleotide exchange factor activity"),
c("GO:0031386","protein tag",0.010,0.8462,0.994,0.000,"protein tag"),
c("GO:0045569","TRAIL binding",0.000,0.8674,0.884,0.000,"TRAIL binding"),
c("GO:1904855","proteasome regulatory particle binding",0.007,0.8673,0.854,0.270,"TRAIL binding"),
c("GO:0032427","GBD domain binding",0.000,0.6971,0.884,0.272,"TRAIL binding"),
c("GO:0045503","dynein light chain binding",0.001,0.8644,0.871,0.281,"TRAIL binding"),
c("GO:0019957","C-C chemokine binding",0.002,0.8599,0.876,0.290,"TRAIL binding"),
c("GO:0043560","insulin receptor substrate binding",0.002,0.7559,0.874,0.295,"TRAIL binding"),
c("GO:0051371","muscle alpha-actinin binding",0.003,0.8619,0.864,0.296,"TRAIL binding"),
c("GO:0098632","protein binding involved in cell-cell adhesion",0.005,0.7860,0.869,0.307,"TRAIL binding"),
c("GO:0043548","phosphatidylinositol 3-kinase binding",0.005,0.7405,0.869,0.307,"TRAIL binding"),
c("GO:0043236","laminin binding",0.006,0.8502,0.869,0.308,"TRAIL binding"),
c("GO:0001099","basal RNA polymerase II transcription machinery binding",0.017,0.8442,0.861,0.327,"TRAIL binding"),
c("GO:0097110","scaffold protein binding",0.007,0.6987,0.867,0.328,"TRAIL binding"),
c("GO:0017147","Wnt-protein binding",0.009,0.7599,0.866,0.331,"TRAIL binding"),
c("GO:0005164","tumor necrosis factor receptor binding",0.011,0.8391,0.853,0.336,"TRAIL binding"),
c("GO:0051117","ATPase binding",0.014,0.8376,0.853,0.340,"TRAIL binding"),
c("GO:0005520","insulin-like growth factor binding",0.014,0.8376,0.862,0.340,"TRAIL binding"),
c("GO:0045296","cadherin binding",0.062,0.8357,0.848,0.372,"TRAIL binding"),
c("GO:0019955","cytokine binding",0.021,0.8350,0.859,0.376,"TRAIL binding"),
c("GO:0001085","RNA polymerase II transcription factor binding",0.033,0.7693,0.854,0.387,"TRAIL binding"),
c("GO:0030276","clathrin binding",0.033,0.7094,0.856,0.387,"TRAIL binding"),
c("GO:0008022","protein C-terminus binding",0.035,0.7194,0.855,0.388,"TRAIL binding"),
c("GO:0030674","protein binding, bridging",0.045,0.7966,0.850,0.395,"TRAIL binding"),
c("GO:0005484","SNAP receptor activity",0.047,0.8133,0.853,0.396,"TRAIL binding"),
c("GO:0043130","ubiquitin binding",0.059,0.8151,0.846,0.403,"TRAIL binding"),
c("GO:0005516","calmodulin binding",0.072,0.7942,0.849,0.408,"TRAIL binding"),
c("GO:0051087","chaperone binding",0.101,0.7749,0.846,0.422,"TRAIL binding"),
c("GO:0019904","protein domain specific binding",0.147,0.7731,0.842,0.445,"TRAIL binding"),
c("GO:0005523","tropomyosin binding",0.007,0.8499,0.856,0.488,"TRAIL binding"),
c("GO:0042802","identical protein binding",0.400,0.7354,0.832,0.495,"TRAIL binding"),
c("GO:0045735","nutrient reservoir activity",0.042,0.7108,0.994,0.000,"nutrient reservoir activity"),
c("GO:0008884","glutathionylspermidine amidase activity",0.000,0.8625,0.931,0.012,"glutathionylspermidine amidase activity"),
c("GO:0005391","sodium:potassium-exchanging ATPase activity",0.006,0.8619,0.853,0.104,"glutathionylspermidine amidase activity"),
c("GO:0061578","Lys63-specific deubiquitinase activity",0.002,0.8219,0.927,0.112,"glutathionylspermidine amidase activity"),
c("GO:0019784","NEDD8-specific protease activity",0.003,0.8539,0.908,0.115,"glutathionylspermidine amidase activity"),
c("GO:0004415","hyalurononglucosaminidase activity",0.006,0.8494,0.914,0.119,"glutathionylspermidine amidase activity"),
c("GO:0004531","deoxyribonuclease II activity",0.015,0.8478,0.875,0.125,"glutathionylspermidine amidase activity"),
c("GO:0019534","toxin transporter activity",0.001,0.7528,0.957,0.211,"glutathionylspermidine amidase activity"),
c("GO:0008521","acetyl-CoA transporter activity",0.008,0.8472,0.952,0.235,"glutathionylspermidine amidase activity"),
c("GO:0042910","xenobiotic transporter activity",0.025,0.7392,0.949,0.255,"glutathionylspermidine amidase activity"),
c("GO:0001681","sialate O-acetylesterase activity",0.001,0.8332,0.898,0.287,"glutathionylspermidine amidase activity"),
c("GO:0008569","ATP-dependent microtubule motor activity, minus-end-directed",0.002,0.8524,0.913,0.289,"glutathionylspermidine amidase activity"),
c("GO:0051032","nucleic acid transmembrane transporter activity",0.002,0.8524,0.943,0.289,"glutathionylspermidine amidase activity"),
c("GO:0004724","magnesium-dependent protein serine/threonine phosphatase activity",0.002,0.8469,0.883,0.300,"glutathionylspermidine amidase activity"),
c("GO:0015204","urea transmembrane transporter activity",0.009,0.8436,0.941,0.309,"glutathionylspermidine amidase activity"),
c("GO:0003860","3-hydroxyisobutyryl-CoA hydrolase activity",0.022,0.8134,0.884,0.340,"glutathionylspermidine amidase activity"),
c("GO:0005319","lipid transporter activity",0.124,0.7691,0.934,0.354,"glutathionylspermidine amidase activity"),
c("GO:0045330","aspartyl esterase activity",0.037,0.8128,0.881,0.359,"glutathionylspermidine amidase activity"),
c("GO:0004053","arginase activity",0.011,0.8245,0.919,0.363,"glutathionylspermidine amidase activity"),
c("GO:0036402","proteasome-activating ATPase activity",0.005,0.8447,0.913,0.366,"glutathionylspermidine amidase activity"),
c("GO:0017116","single-stranded DNA-dependent ATP-dependent DNA helicase activity",0.007,0.8229,0.907,0.371,"glutathionylspermidine amidase activity"),
c("GO:0070003","threonine-type peptidase activity",0.127,0.7750,0.895,0.373,"glutathionylspermidine amidase activity"),
c("GO:0005452","inorganic anion exchanger activity",0.021,0.8302,0.928,0.380,"glutathionylspermidine amidase activity"),
c("GO:0004528","phosphodiesterase I activity",0.003,0.8398,0.876,0.402,"glutathionylspermidine amidase activity"),
c("GO:0008484","sulfuric ester hydrolase activity",0.142,0.7414,0.870,0.405,"glutathionylspermidine amidase activity"),
c("GO:0008832","dGTPase activity",0.004,0.7982,0.883,0.414,"glutathionylspermidine amidase activity"),
c("GO:0008995","ribonuclease E activity",0.009,0.8291,0.882,0.414,"glutathionylspermidine amidase activity"),
c("GO:0016977","chitosanase activity",0.004,0.8484,0.915,0.418,"glutathionylspermidine amidase activity"),
c("GO:0016161","beta-amylase activity",0.005,0.8488,0.915,0.422,"glutathionylspermidine amidase activity"),
c("GO:0008519","ammonium transmembrane transporter activity",0.086,0.7706,0.926,0.430,"glutathionylspermidine amidase activity"),
c("GO:0008186","RNA-dependent ATPase activity",0.106,0.7984,0.896,0.437,"glutathionylspermidine amidase activity"),
c("GO:0003924","GTPase activity",1.135,0.6826,0.885,0.443,"glutathionylspermidine amidase activity"),
c("GO:0004568","chitinase activity",0.021,0.8154,0.908,0.454,"glutathionylspermidine amidase activity"),
c("GO:0033925","mannosyl-glycoprotein endo-beta-N-acetylglucosaminidase activity",0.006,0.6942,0.914,0.457,"glutathionylspermidine amidase activity"),
c("GO:0042242","cobyrinic acid a,c-diamide synthase activity",0.016,0.8147,0.916,0.458,"glutathionylspermidine amidase activity"),
c("GO:0004647","phosphoserine phosphatase activity",0.027,0.8132,0.868,0.481,"glutathionylspermidine amidase activity"),
c("GO:0052629","phosphatidylinositol-3,5-bisphosphate 3-phosphatase activity",0.002,0.7885,0.882,0.482,"glutathionylspermidine amidase activity"),
c("GO:0097199","cysteine-type endopeptidase activity involved in apoptotic signaling pathway",0.001,0.8307,0.876,0.483,"glutathionylspermidine amidase activity"),
c("GO:0019198","transmembrane receptor protein phosphatase activity",0.001,0.7003,0.823,0.484,"glutathionylspermidine amidase activity"),
c("GO:0004000","adenosine deaminase activity",0.051,0.7823,0.912,0.484,"glutathionylspermidine amidase activity"),
c("GO:1990404","protein ADP-ribosylase activity",0.000,0.8592,0.930,0.012,"protein ADP-ribosylase activity"),
c("GO:0015016","[heparan sulfate]-glucosamine N-sulfotransferase activity",0.004,0.8559,0.930,0.109,"protein ADP-ribosylase activity"),
c("GO:0004692","cGMP-dependent protein kinase activity",0.003,0.8516,0.903,0.120,"protein ADP-ribosylase activity"),
c("GO:0004057","arginyltransferase activity",0.015,0.8253,0.923,0.130,"protein ADP-ribosylase activity"),
c("GO:0004478","methionine adenosyltransferase activity",0.046,0.7899,0.927,0.149,"protein ADP-ribosylase activity"),
c("GO:0004084","branched-chain-amino-acid transaminase activity",0.046,0.7889,0.923,0.160,"protein ADP-ribosylase activity"),
c("GO:0009008","DNA-methyltransferase activity",0.079,0.7629,0.914,0.166,"protein ADP-ribosylase activity"),
c("GO:0004842","ubiquitin-protein transferase activity",0.352,0.7378,0.909,0.192,"protein ADP-ribosylase activity"),
c("GO:0000829","inositol heptakisphosphate kinase activity",0.001,0.8462,0.910,0.241,"protein ADP-ribosylase activity"),
c("GO:0004781","sulfate adenylyltransferase (ATP) activity",0.046,0.7860,0.900,0.250,"protein ADP-ribosylase activity"),
c("GO:0016307","phosphatidylinositol phosphate kinase activity",0.032,0.8228,0.897,0.317,"protein ADP-ribosylase activity"),
c("GO:0004349","glutamate 5-kinase activity",0.032,0.7586,0.901,0.327,"protein ADP-ribosylase activity"),
c("GO:0016780","phosphotransferase activity, for other substituted phosphate groups",0.327,0.7215,0.892,0.337,"protein ADP-ribosylase activity"),
c("GO:0004583","dolichyl-phosphate-glucose-glycolipid alpha-glucosyltransferase activity",0.006,0.8538,0.919,0.347,"protein ADP-ribosylase activity"),
c("GO:0004335","galactokinase activity",0.024,0.8091,0.897,0.356,"protein ADP-ribosylase activity"),
c("GO:0004020","adenylylsulfate kinase activity",0.027,0.7942,0.898,0.358,"protein ADP-ribosylase activity"),
c("GO:0004143","diacylglycerol kinase activity",0.036,0.8087,0.896,0.365,"protein ADP-ribosylase activity"),
c("GO:0004743","pyruvate kinase activity",0.055,0.7846,0.896,0.377,"protein ADP-ribosylase activity"),
c("GO:0004713","protein tyrosine kinase activity",0.138,0.7716,0.885,0.413,"protein ADP-ribosylase activity"),
c("GO:0019706","protein-cysteine S-palmitoyltransferase activity",0.068,0.8020,0.913,0.428,"protein ADP-ribosylase activity"),
c("GO:0004687","myosin light chain kinase activity",0.002,0.7358,0.906,0.428,"protein ADP-ribosylase activity"),
c("GO:0003951","NAD+ kinase activity",0.128,0.7398,0.888,0.440,"protein ADP-ribosylase activity"),
c("GO:0003886","DNA (cytosine-5-)-methyltransferase activity",0.023,0.7899,0.917,0.448,"protein ADP-ribosylase activity"),
c("GO:0052724","inositol hexakisphosphate 3-kinase activity",0.000,0.8451,0.909,0.469,"protein ADP-ribosylase activity"),
c("GO:0015018","galactosylgalactosylxylosylprotein 3-beta-glucuronosyltransferase activity",0.009,0.8495,0.916,0.487,"protein ADP-ribosylase activity"),
c("GO:0003968","RNA-directed 5'-3' RNA polymerase activity",0.034,0.7242,0.900,0.492,"protein ADP-ribosylase activity"),
c("GO:0033857","diphosphoinositol-pentakisphosphate kinase activity",0.002,0.8450,0.907,0.499,"protein ADP-ribosylase activity"),
c("GO:0000250","lanosterol synthase activity",0.001,0.8385,0.967,0.012,"lanosterol synthase activity"),
c("GO:0003917","DNA topoisomerase type I activity",0.084,0.7649,0.965,0.369,"lanosterol synthase activity"),
c("GO:0008885","glutathionylspermidine synthase activity",0.001,0.8369,0.959,0.012,"glutathionylspermidine synthase activity"),
c("GO:0004816","asparagine-tRNA ligase activity",0.027,0.8011,0.951,0.320,"glutathionylspermidine synthase activity"),
c("GO:0003910","DNA ligase (ATP) activity",0.055,0.7877,0.953,0.410,"glutathionylspermidine synthase activity"),
c("GO:0030272","5-formyltetrahydrofolate cyclo-ligase activity",0.031,0.7946,0.953,0.420,"glutathionylspermidine synthase activity"),
c("GO:0008641","small protein activating enzyme activity",0.115,0.7666,0.951,0.452,"glutathionylspermidine synthase activity"),
c("GO:0046570","methylthioribulose 1-phosphate dehydratase activity",0.008,0.8360,0.966,0.013,"methylthioribulose 1-phosphate dehydratase activity"),
c("GO:0004383","guanylate cyclase activity",0.023,0.8327,0.962,0.359,"methylthioribulose 1-phosphate dehydratase activity"),
c("GO:0016846","carbon-sulfur lyase activity",0.143,0.7513,0.962,0.429,"methylthioribulose 1-phosphate dehydratase activity"),
c("GO:0004803","transposase activity",0.307,0.7233,0.973,0.019,"transposase activity"),
c("GO:0070492","oligosaccharide binding",0.006,0.8604,0.968,0.023,"oligosaccharide binding"),
c("GO:0005534","galactose binding",0.005,0.8079,0.963,0.499,"oligosaccharide binding"),
c("GO:0008430","selenium binding",0.006,0.8478,0.977,0.027,"selenium binding"),
c("GO:1902936","phosphatidylinositol bisphosphate binding",0.024,0.8336,0.949,0.029,"phosphatidylinositol bisphosphate binding"),
c("GO:0071949","FAD binding",0.264,0.7093,0.953,0.173,"phosphatidylinositol bisphosphate binding"),
c("GO:0050840","extracellular matrix binding",0.011,0.7648,0.976,0.030,"extracellular matrix binding"),
c("GO:0000339","RNA cap binding",0.025,0.8209,0.966,0.031,"RNA cap binding"),
c("GO:0000977","RNA polymerase II regulatory region sequence-specific DNA binding",0.160,0.7709,0.962,0.166,"RNA cap binding"),
c("GO:0003697","single-stranded DNA binding",0.219,0.7375,0.965,0.289,"RNA cap binding"),
c("GO:0003743","translation initiation factor activity",0.411,0.7303,0.960,0.405,"RNA cap binding"),
c("GO:0003725","double-stranded RNA binding",0.084,0.7025,0.964,0.443,"RNA cap binding"),
c("GO:0042277","peptide binding",0.089,0.7878,0.970,0.034,"peptide binding"),
c("GO:0008061","chitin binding",0.114,0.7775,0.971,0.038,"chitin binding"),
c("GO:0035438","cyclic-di-GMP binding",0.056,0.7722,0.956,0.204,"chitin binding"),
c("GO:0043531","ADP binding",0.183,0.7011,0.957,0.223,"chitin binding"),
c("GO:0008289","lipid binding",0.519,0.7249,0.971,0.043,"lipid binding"),
c("GO:0044877","macromolecular complex binding",0.740,0.7110,0.971,0.051,"macromolecular complex binding"),
c("GO:0030246","carbohydrate binding",0.723,0.7009,0.971,0.053,"carbohydrate binding"),
c("GO:0030955","potassium ion binding",0.074,0.7677,0.968,0.094,"potassium ion binding"),
c("GO:0005507","copper ion binding",0.315,0.7228,0.965,0.244,"potassium ion binding"),
c("GO:0005509","calcium ion binding",0.967,0.7034,0.963,0.304,"potassium ion binding"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
