

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0003700","transcription factor activity, sequence-specific DNA binding",4.217,0.6190,0.982,0.000,"transcription factor activity, sequence-specific DNA binding"),
c("GO:0003712","transcription cofactor activity",0.250,0.3701,0.981,0.000,"transcription cofactor activity"),
c("GO:0004484","mRNA guanylyltransferase activity",0.008,0.8413,0.928,0.000,"mRNA guanylyltransferase activity"),
c("GO:0004125","L-seryl-tRNASec selenium transferase activity",0.007,0.4469,0.947,0.130,"mRNA guanylyltransferase activity"),
c("GO:0008476","protein-tyrosine sulfotransferase activity",0.010,0.8351,0.946,0.132,"mRNA guanylyltransferase activity"),
c("GO:0016757","transferase activity, transferring glycosyl groups",1.986,0.6546,0.923,0.187,"mRNA guanylyltransferase activity"),
c("GO:0003950","NAD+ ADP-ribosyltransferase activity",0.033,0.4650,0.942,0.206,"mRNA guanylyltransferase activity"),
c("GO:0004402","histone acetyltransferase activity",0.066,0.4170,0.940,0.219,"mRNA guanylyltransferase activity"),
c("GO:0004697","protein kinase C activity",0.016,0.8410,0.917,0.248,"mRNA guanylyltransferase activity"),
c("GO:0004842","ubiquitin-protein transferase activity",0.352,0.5910,0.926,0.257,"mRNA guanylyltransferase activity"),
c("GO:0008483","transaminase activity",0.736,0.5087,0.929,0.279,"mRNA guanylyltransferase activity"),
c("GO:0008168","methyltransferase activity",2.784,0.6344,0.921,0.328,"mRNA guanylyltransferase activity"),
c("GO:0004143","diacylglycerol kinase activity",0.036,0.3401,0.915,0.350,"mRNA guanylyltransferase activity"),
c("GO:0004713","protein tyrosine kinase activity",0.138,0.7709,0.905,0.427,"mRNA guanylyltransferase activity"),
c("GO:0003951","NAD+ kinase activity",0.128,0.3368,0.908,0.440,"mRNA guanylyltransferase activity"),
c("GO:0004714","transmembrane receptor protein tyrosine kinase activity",0.045,0.7844,0.860,0.458,"mRNA guanylyltransferase activity"),
c("GO:0004867","serine-type endopeptidase inhibitor activity",0.068,0.7768,0.949,0.000,"serine-type endopeptidase inhibitor activity"),
c("GO:0005030","neurotrophin receptor activity",0.002,0.6049,0.947,0.000,"neurotrophin receptor activity"),
c("GO:0005044","scavenger receptor activity",0.041,0.4472,0.940,0.374,"neurotrophin receptor activity"),
c("GO:0005198","structural molecule activity",3.268,0.4403,0.990,0.000,"structural molecule activity"),
c("GO:0005201","extracellular matrix structural constituent",0.028,0.6312,0.979,0.000,"extracellular matrix structural constituent"),
c("GO:0005452","inorganic anion exchanger activity",0.021,0.8254,0.888,0.000,"inorganic anion exchanger activity"),
c("GO:0019534","toxin transporter activity",0.001,0.4030,0.934,0.225,"inorganic anion exchanger activity"),
c("GO:0015562","efflux transmembrane transporter activity",0.005,0.4453,0.919,0.289,"inorganic anion exchanger activity"),
c("GO:0005372","water transmembrane transporter activity",0.010,0.5336,0.910,0.335,"inorganic anion exchanger activity"),
c("GO:0015267","channel activity",0.699,0.6774,0.867,0.398,"inorganic anion exchanger activity"),
c("GO:0005375","copper ion transmembrane transporter activity",0.033,0.5338,0.895,0.412,"inorganic anion exchanger activity"),
c("GO:0009055","electron carrier activity",1.275,0.3367,0.990,0.000,"electron carrier activity"),
c("GO:0030971","receptor tyrosine kinase binding",0.012,0.8451,0.824,0.000,"receptor tyrosine kinase binding"),
c("GO:0097677","STAT family protein binding",0.000,0.4733,0.873,0.275,"receptor tyrosine kinase binding"),
c("GO:0043121","neurotrophin binding",0.002,0.4427,0.859,0.297,"receptor tyrosine kinase binding"),
c("GO:0032794","GTPase activating protein binding",0.003,0.3732,0.859,0.305,"receptor tyrosine kinase binding"),
c("GO:0043548","phosphatidylinositol 3-kinase binding",0.005,0.3973,0.854,0.316,"receptor tyrosine kinase binding"),
c("GO:0043236","laminin binding",0.006,0.4935,0.854,0.317,"receptor tyrosine kinase binding"),
c("GO:0017147","Wnt-protein binding",0.009,0.4536,0.850,0.324,"receptor tyrosine kinase binding"),
c("GO:0046982","protein heterodimerization activity",0.280,0.7508,0.813,0.400,"receptor tyrosine kinase binding"),
c("GO:0043621","protein self-association",0.014,0.6076,0.847,0.404,"receptor tyrosine kinase binding"),
c("GO:0031369","translation initiation factor binding",0.030,0.3333,0.839,0.426,"receptor tyrosine kinase binding"),
c("GO:0019838","growth factor binding",0.034,0.4171,0.838,0.430,"receptor tyrosine kinase binding"),
c("GO:0005516","calmodulin binding",0.072,0.3738,0.831,0.455,"receptor tyrosine kinase binding"),
c("GO:0042393","histone binding",0.087,0.4327,0.829,0.462,"receptor tyrosine kinase binding"),
c("GO:0050839","cell adhesion molecule binding",0.088,0.6460,0.829,0.462,"receptor tyrosine kinase binding"),
c("GO:0019904","protein domain specific binding",0.147,0.6721,0.823,0.481,"receptor tyrosine kinase binding"),
c("GO:0016174","NAD(P)H oxidase activity",0.003,0.7979,0.952,0.014,"NAD(P)H oxidase activity"),
c("GO:0004601","peroxidase activity",0.377,0.7205,0.953,0.225,"NAD(P)H oxidase activity"),
c("GO:0050570","4-hydroxythreonine-4-phosphate dehydrogenase activity",0.022,0.6585,0.959,0.256,"NAD(P)H oxidase activity"),
c("GO:0051213","dioxygenase activity",0.494,0.7086,0.952,0.329,"NAD(P)H oxidase activity"),
c("GO:0016705","oxidoreductase activity, acting on paired donors, with incorporation or reduction of molecular oxygen",1.177,0.6889,0.949,0.368,"NAD(P)H oxidase activity"),
c("GO:0004497","monooxygenase activity",0.947,0.5412,0.950,0.394,"NAD(P)H oxidase activity"),
c("GO:0004053","arginase activity",0.011,0.8238,0.927,0.015,"arginase activity"),
c("GO:0004651","polynucleotide 5'-phosphatase activity",0.007,0.8231,0.907,0.125,"arginase activity"),
c("GO:0004560","alpha-L-fucosidase activity",0.033,0.8031,0.900,0.136,"arginase activity"),
c("GO:0003774","motor activity",0.399,0.7265,0.893,0.172,"arginase activity"),
c("GO:0004190","aspartic-type endopeptidase activity",0.269,0.7071,0.899,0.204,"arginase activity"),
c("GO:0004423","iduronate-2-sulfatase activity",0.000,0.8135,0.916,0.266,"arginase activity"),
c("GO:0008233","peptidase activity",4.049,0.5313,0.895,0.267,"arginase activity"),
c("GO:0090554","phosphatidylcholine-translocating ATPase activity",0.001,0.5383,0.864,0.288,"arginase activity"),
c("GO:0008484","sulfuric ester hydrolase activity",0.142,0.7446,0.895,0.362,"arginase activity"),
c("GO:0003777","microtubule motor activity",0.218,0.4773,0.898,0.431,"arginase activity"),
c("GO:0004767","sphingomyelin phosphodiesterase activity",0.007,0.3842,0.907,0.442,"arginase activity"),
c("GO:0008448","N-acetylglucosamine-6-phosphate deacetylase activity",0.023,0.8053,0.924,0.453,"arginase activity"),
c("GO:0046559","alpha-glucuronidase activity",0.005,0.7067,0.910,0.461,"arginase activity"),
c("GO:0008534","oxidized purine nucleobase lesion DNA N-glycosylase activity",0.035,0.3982,0.872,0.492,"arginase activity"),
c("GO:0016874","ligase activity",3.540,0.5440,0.968,0.023,"ligase activity"),
c("GO:0004383","guanylate cyclase activity",0.023,0.3670,0.972,0.024,"guanylate cyclase activity"),
c("GO:0030169","low-density lipoprotein particle binding",0.003,0.6045,0.943,0.027,"low-density lipoprotein particle binding"),
c("GO:0001540","beta-amyloid binding",0.007,0.5791,0.962,0.028,"beta-amyloid binding"),
c("GO:0031418","L-ascorbic acid binding",0.062,0.7964,0.925,0.032,"L-ascorbic acid binding"),
c("GO:0005507","copper ion binding",0.315,0.7114,0.925,0.111,"L-ascorbic acid binding"),
c("GO:0071949","FAD binding",0.264,0.7091,0.903,0.185,"L-ascorbic acid binding"),
c("GO:0043168","anion binding",20.942,0.4086,0.905,0.199,"L-ascorbic acid binding"),
c("GO:0005543","phospholipid binding",0.270,0.6676,0.923,0.209,"L-ascorbic acid binding"),
c("GO:0005509","calcium ion binding",0.967,0.7030,0.921,0.304,"L-ascorbic acid binding"),
c("GO:0000287","magnesium ion binding",1.785,0.5174,0.917,0.365,"L-ascorbic acid binding"),
c("GO:0010181","FMN binding",0.698,0.3834,0.891,0.499,"L-ascorbic acid binding"),
c("GO:0008061","chitin binding",0.114,0.7749,0.940,0.037,"chitin binding"),
c("GO:0008201","heparin binding",0.029,0.5115,0.932,0.195,"chitin binding"),
c("GO:0005525","GTP binding",1.783,0.6623,0.880,0.269,"chitin binding"),
c("GO:0019001","guanyl nucleotide binding",1.846,0.3690,0.902,0.382,"chitin binding"),
c("GO:0030246","carbohydrate binding",0.723,0.7014,0.950,0.044,"carbohydrate binding"),
c("GO:0008144","drug binding",0.178,0.3671,0.955,0.046,"drug binding"),
c("GO:0008289","lipid binding",0.519,0.5629,0.951,0.051,"lipid binding"),
c("GO:0016491","oxidoreductase activity",12.783,0.5484,0.965,0.053,"oxidoreductase activity"),
c("GO:0043565","sequence-specific DNA binding",2.222,0.6669,0.913,0.059,"sequence-specific DNA binding"),
c("GO:0020037","heme binding",1.357,0.6374,0.933,0.129,"sequence-specific DNA binding"),
c("GO:0003676","nucleic acid binding",21.226,0.5166,0.908,0.195,"sequence-specific DNA binding"),
c("GO:0003746","translation elongation factor activity",0.369,0.4606,0.921,0.260,"sequence-specific DNA binding"),
c("GO:0030627","pre-mRNA 5'-splice site binding",0.001,0.4315,0.946,0.333,"sequence-specific DNA binding"),
c("GO:0001012","RNA polymerase II regulatory region DNA binding",0.160,0.5383,0.930,0.354,"sequence-specific DNA binding"),
c("GO:0003723","RNA binding",5.283,0.5723,0.909,0.362,"sequence-specific DNA binding"),
c("GO:0003684","damaged DNA binding",0.291,0.3855,0.927,0.376,"sequence-specific DNA binding"),
c("GO:0003690","double-stranded DNA binding",0.508,0.5121,0.924,0.399,"sequence-specific DNA binding"),
c("GO:0003677","DNA binding",12.549,0.5601,0.899,0.487,"sequence-specific DNA binding"),
c("GO:0051539","4 iron, 4 sulfur cluster binding",1.007,0.3660,0.949,0.062,"4 iron, 4 sulfur cluster binding"),
c("GO:0005515","protein binding",4.410,0.3642,0.941,0.075,"protein binding"),
c("GO:0016787","hydrolase activity",22.294,0.5239,0.964,0.080,"hydrolase activity"),
c("GO:0016740","transferase activity",21.036,0.4974,0.964,0.093,"transferase activity"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
