

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0003700","transcription factor activity, sequence-specific DNA binding",4.217,0.6199,0.995,0.000,"transcription factor activity, sequence-specific DNA binding"),
c("GO:0003712","transcription cofactor activity",0.250,0.7573,0.984,0.000,"transcription cofactor activity"),
c("GO:0004965","G-protein coupled GABA receptor activity",0.009,0.8500,0.920,0.000,"G-protein coupled GABA receptor activity"),
c("GO:0005030","neurotrophin receptor activity",0.002,0.8095,0.935,0.369,"G-protein coupled GABA receptor activity"),
c("GO:0071936","coreceptor activity involved in Wnt signaling pathway",0.002,0.6944,0.934,0.371,"G-protein coupled GABA receptor activity"),
c("GO:0005044","scavenger receptor activity",0.041,0.8175,0.932,0.410,"G-protein coupled GABA receptor activity"),
c("GO:0009881","photoreceptor activity",0.023,0.7969,0.926,0.435,"G-protein coupled GABA receptor activity"),
c("GO:0005034","osmosensor activity",0.001,0.7563,0.929,0.437,"G-protein coupled GABA receptor activity"),
c("GO:0038064","collagen receptor activity",0.003,0.6161,0.924,0.469,"G-protein coupled GABA receptor activity"),
c("GO:0001614","purinergic nucleotide receptor activity",0.012,0.8467,0.919,0.500,"G-protein coupled GABA receptor activity"),
c("GO:0042813","Wnt-activated receptor activity",0.010,0.8433,0.920,0.505,"G-protein coupled GABA receptor activity"),
c("GO:0004675","transmembrane receptor protein serine/threonine kinase activity",0.025,0.8233,0.832,0.531,"G-protein coupled GABA receptor activity"),
c("GO:0016500","protein-hormone receptor activity",0.008,0.8457,0.920,0.536,"G-protein coupled GABA receptor activity"),
c("GO:0004697","protein kinase C activity",0.016,0.8194,0.900,0.536,"G-protein coupled GABA receptor activity"),
c("GO:0017154","semaphorin receptor activity",0.014,0.7319,0.918,0.537,"G-protein coupled GABA receptor activity"),
c("GO:0004683","calmodulin-dependent protein kinase activity",0.023,0.8076,0.898,0.547,"G-protein coupled GABA receptor activity"),
c("GO:0016917","GABA receptor activity",0.022,0.6707,0.916,0.551,"G-protein coupled GABA receptor activity"),
c("GO:0004896","cytokine receptor activity",0.031,0.6639,0.915,0.562,"G-protein coupled GABA receptor activity"),
c("GO:0004707","MAP kinase activity",0.038,0.8129,0.846,0.564,"G-protein coupled GABA receptor activity"),
c("GO:0038023","signaling receptor activity",2.150,0.6920,0.906,0.604,"G-protein coupled GABA receptor activity"),
c("GO:0019199","transmembrane receptor protein kinase activity",0.071,0.7558,0.828,0.634,"G-protein coupled GABA receptor activity"),
c("GO:0008066","glutamate receptor activity",0.078,0.6178,0.910,0.640,"G-protein coupled GABA receptor activity"),
c("GO:0001653","peptide receptor activity",0.093,0.6475,0.919,0.650,"G-protein coupled GABA receptor activity"),
c("GO:0030594","neurotransmitter receptor activity",0.114,0.6428,0.918,0.663,"G-protein coupled GABA receptor activity"),
c("GO:0005198","structural molecule activity",3.268,0.5895,0.994,0.000,"structural molecule activity"),
c("GO:0005199","structural constituent of cell wall",0.017,0.8375,0.981,0.000,"structural constituent of cell wall"),
c("GO:0030197","extracellular matrix constituent, lubricant activity",0.000,0.7041,0.984,0.279,"structural constituent of cell wall"),
c("GO:0008307","structural constituent of muscle",0.006,0.6463,0.982,0.359,"structural constituent of cell wall"),
c("GO:0005201","extracellular matrix structural constituent",0.028,0.7836,0.981,0.393,"structural constituent of cell wall"),
c("GO:0003735","structural constituent of ribosome",2.679,0.5977,0.977,0.561,"structural constituent of cell wall"),
c("GO:0042302","structural constituent of cuticle",0.063,0.5964,0.980,0.603,"structural constituent of cell wall"),
c("GO:0009055","electron carrier activity",1.275,0.6255,0.994,0.000,"electron carrier activity"),
c("GO:0016209","antioxidant activity",0.710,0.6963,0.994,0.000,"antioxidant activity"),
c("GO:0031386","protein tag",0.010,0.6270,0.994,0.000,"protein tag"),
c("GO:0045182","translation regulator activity",0.010,0.6857,0.994,0.000,"translation regulator activity"),
c("GO:0045735","nutrient reservoir activity",0.042,0.6129,0.994,0.000,"nutrient reservoir activity"),
c("GO:0051032","nucleic acid transmembrane transporter activity",0.002,0.8575,0.948,0.000,"nucleic acid transmembrane transporter activity"),
c("GO:0042910","xenobiotic transporter activity",0.025,0.6884,0.954,0.238,"nucleic acid transmembrane transporter activity"),
c("GO:0030171","voltage-gated proton channel activity",0.000,0.8563,0.935,0.257,"nucleic acid transmembrane transporter activity"),
c("GO:0046961","proton-transporting ATPase activity, rotational mechanism",0.048,0.8114,0.873,0.363,"nucleic acid transmembrane transporter activity"),
c("GO:0005355","glucose transmembrane transporter activity",0.021,0.6520,0.944,0.366,"nucleic acid transmembrane transporter activity"),
c("GO:0003774","motor activity",0.399,0.7299,0.920,0.381,"nucleic acid transmembrane transporter activity"),
c("GO:0003777","microtubule motor activity",0.218,0.7652,0.921,0.431,"nucleic acid transmembrane transporter activity"),
c("GO:0022857","transmembrane transporter activity",5.870,0.5757,0.933,0.431,"nucleic acid transmembrane transporter activity"),
c("GO:0008271","secondary active sulfate transmembrane transporter activity",0.069,0.7826,0.931,0.464,"nucleic acid transmembrane transporter activity"),
c("GO:0003678","DNA helicase activity",0.530,0.7036,0.918,0.466,"nucleic acid transmembrane transporter activity"),
c("GO:0003924","GTPase activity",1.135,0.6826,0.913,0.517,"nucleic acid transmembrane transporter activity"),
c("GO:0004931","extracellular ATP-gated cation channel activity",0.006,0.8528,0.861,0.523,"nucleic acid transmembrane transporter activity"),
c("GO:0004386","helicase activity",1.222,0.6712,0.912,0.565,"nucleic acid transmembrane transporter activity"),
c("GO:0015301","anion:anion antiporter activity",0.016,0.6847,0.938,0.575,"nucleic acid transmembrane transporter activity"),
c("GO:0008381","mechanically-gated ion channel activity",0.015,0.7965,0.927,0.585,"nucleic acid transmembrane transporter activity"),
c("GO:0005227","calcium activated cation channel activity",0.018,0.5884,0.923,0.629,"nucleic acid transmembrane transporter activity"),
c("GO:0046873","metal ion transmembrane transporter activity",0.999,0.6878,0.920,0.635,"nucleic acid transmembrane transporter activity"),
c("GO:0016887","ATPase activity",4.560,0.6145,0.902,0.670,"nucleic acid transmembrane transporter activity"),
c("GO:0005242","inward rectifier potassium channel activity",0.017,0.8380,0.854,0.676,"nucleic acid transmembrane transporter activity"),
c("GO:0042626","ATPase activity, coupled to transmembrane movement of substances",1.541,0.6743,0.850,0.691,"nucleic acid transmembrane transporter activity"),
c("GO:0008574","ATP-dependent microtubule motor activity, plus-end-directed",0.006,0.7484,0.936,0.695,"nucleic acid transmembrane transporter activity"),
c("GO:0061575","cyclin-dependent protein serine/threonine kinase activator activity",0.008,0.8491,0.959,0.000,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0019871","sodium channel inhibitor activity",0.001,0.5839,0.964,0.422,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0017112","Rab guanyl-nucleotide exchange factor activity",0.012,0.8447,0.957,0.482,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0005085","guanyl-nucleotide exchange factor activity",0.244,0.7555,0.953,0.590,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0019888","protein phosphatase regulator activity",0.060,0.6022,0.955,0.662,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0019208","phosphatase regulator activity",0.074,0.7446,0.955,0.672,"cyclin-dependent protein serine/threonine kinase activator activity"),
c("GO:0070547","L-tyrosine aminotransferase activity",0.002,0.8598,0.944,0.000,"L-tyrosine aminotransferase activity"),
c("GO:0004430","1-phosphatidylinositol 4-kinase activity",0.005,0.8498,0.909,0.119,"L-tyrosine aminotransferase activity"),
c("GO:0015018","galactosylgalactosylxylosylprotein 3-beta-glucuronosyltransferase activity",0.009,0.8495,0.932,0.128,"L-tyrosine aminotransferase activity"),
c("GO:0004057","arginyltransferase activity",0.015,0.8249,0.930,0.136,"L-tyrosine aminotransferase activity"),
c("GO:0018024","histone-lysine N-methyltransferase activity",0.070,0.7969,0.924,0.153,"L-tyrosine aminotransferase activity"),
c("GO:0004364","glutathione transferase activity",0.033,0.7945,0.935,0.161,"L-tyrosine aminotransferase activity"),
c("GO:0008146","sulfotransferase activity",0.093,0.7789,0.927,0.173,"L-tyrosine aminotransferase activity"),
c("GO:0004842","ubiquitin-protein transferase activity",0.352,0.7378,0.916,0.195,"L-tyrosine aminotransferase activity"),
c("GO:0004484","mRNA guanylyltransferase activity",0.008,0.8457,0.917,0.233,"L-tyrosine aminotransferase activity"),
c("GO:0033857","diphosphoinositol-pentakisphosphate kinase activity",0.002,0.8473,0.915,0.253,"L-tyrosine aminotransferase activity"),
c("GO:0016757","transferase activity, transferring glycosyl groups",1.986,0.6570,0.912,0.257,"L-tyrosine aminotransferase activity"),
c("GO:0046934","phosphatidylinositol-4,5-bisphosphate 3-kinase activity",0.001,0.8398,0.911,0.277,"L-tyrosine aminotransferase activity"),
c("GO:0004703","G-protein coupled receptor kinase activity",0.006,0.8465,0.905,0.298,"L-tyrosine aminotransferase activity"),
c("GO:0016307","phosphatidylinositol phosphate kinase activity",0.032,0.8234,0.903,0.328,"L-tyrosine aminotransferase activity"),
c("GO:0016746","transferase activity, transferring acyl groups",2.893,0.6357,0.910,0.330,"L-tyrosine aminotransferase activity"),
c("GO:0004143","diacylglycerol kinase activity",0.036,0.8087,0.902,0.365,"L-tyrosine aminotransferase activity"),
c("GO:0004594","pantothenate kinase activity",0.044,0.7879,0.901,0.372,"L-tyrosine aminotransferase activity"),
c("GO:0004713","protein tyrosine kinase activity",0.138,0.7719,0.890,0.407,"L-tyrosine aminotransferase activity"),
c("GO:0016772","transferase activity, transferring phosphorus-containing groups",8.504,0.5763,0.900,0.410,"L-tyrosine aminotransferase activity"),
c("GO:0019706","protein-cysteine S-palmitoyltransferase activity",0.068,0.8016,0.922,0.428,"L-tyrosine aminotransferase activity"),
c("GO:0004652","polynucleotide adenylyltransferase activity",0.022,0.7851,0.911,0.432,"L-tyrosine aminotransferase activity"),
c("GO:0003951","NAD+ kinase activity",0.128,0.7590,0.894,0.440,"L-tyrosine aminotransferase activity"),
c("GO:0003950","NAD+ ADP-ribosyltransferase activity",0.033,0.8215,0.927,0.442,"L-tyrosine aminotransferase activity"),
c("GO:0004715","non-membrane spanning protein tyrosine kinase activity",0.042,0.8069,0.896,0.455,"L-tyrosine aminotransferase activity"),
c("GO:0016773","phosphotransferase activity, alcohol group as acceptor",4.703,0.6227,0.874,0.468,"L-tyrosine aminotransferase activity"),
c("GO:0052724","inositol hexakisphosphate 3-kinase activity",0.000,0.8472,0.916,0.479,"L-tyrosine aminotransferase activity"),
c("GO:0000829","inositol heptakisphosphate kinase activity",0.001,0.8472,0.917,0.499,"L-tyrosine aminotransferase activity"),
c("GO:0016409","palmitoyltransferase activity",0.074,0.7968,0.922,0.509,"L-tyrosine aminotransferase activity"),
c("GO:1990817","RNA adenylyltransferase activity",0.000,0.7976,0.933,0.519,"L-tyrosine aminotransferase activity"),
c("GO:0008171","O-methyltransferase activity",0.247,0.7358,0.920,0.525,"L-tyrosine aminotransferase activity"),
c("GO:0008374","O-acyltransferase activity",0.189,0.7451,0.917,0.548,"L-tyrosine aminotransferase activity"),
c("GO:0008378","galactosyltransferase activity",0.047,0.8105,0.925,0.549,"L-tyrosine aminotransferase activity"),
c("GO:0003887","DNA-directed DNA polymerase activity",0.456,0.7101,0.893,0.559,"L-tyrosine aminotransferase activity"),
c("GO:0016758","transferase activity, transferring hexosyl groups",0.898,0.6958,0.909,0.620,"L-tyrosine aminotransferase activity"),
c("GO:0008476","protein-tyrosine sulfotransferase activity",0.010,0.8339,0.936,0.669,"L-tyrosine aminotransferase activity"),
c("GO:0008080","N-acetyltransferase activity",1.029,0.6805,0.905,0.681,"L-tyrosine aminotransferase activity"),
c("GO:0070976","TIR domain binding",0.000,0.8616,0.846,0.000,"TIR domain binding"),
c("GO:0017147","Wnt-protein binding",0.009,0.8488,0.833,0.274,"TIR domain binding"),
c("GO:0045503","dynein light chain binding",0.001,0.7759,0.848,0.283,"TIR domain binding"),
c("GO:0048407","platelet-derived growth factor binding",0.002,0.5885,0.843,0.298,"TIR domain binding"),
c("GO:0043560","insulin receptor substrate binding",0.002,0.7681,0.843,0.298,"TIR domain binding"),
c("GO:0070064","proline-rich region binding",0.004,0.6193,0.839,0.306,"TIR domain binding"),
c("GO:0043548","phosphatidylinositol 3-kinase binding",0.005,0.7553,0.837,0.311,"TIR domain binding"),
c("GO:0005154","epidermal growth factor receptor binding",0.006,0.8453,0.821,0.313,"TIR domain binding"),
c("GO:0030544","Hsp70 protein binding",0.006,0.8448,0.835,0.314,"TIR domain binding"),
c("GO:0001103","RNA polymerase II repressing transcription factor binding",0.007,0.6301,0.835,0.315,"TIR domain binding"),
c("GO:0046332","SMAD binding",0.017,0.8456,0.827,0.330,"TIR domain binding"),
c("GO:0001784","phosphotyrosine binding",0.009,0.6071,0.832,0.331,"TIR domain binding"),
c("GO:0002039","p53 binding",0.013,0.6813,0.829,0.339,"TIR domain binding"),
c("GO:0043621","protein self-association",0.014,0.6179,0.829,0.339,"TIR domain binding"),
c("GO:0047485","protein N-terminus binding",0.016,0.5996,0.827,0.342,"TIR domain binding"),
c("GO:0045296","cadherin binding",0.062,0.8414,0.811,0.371,"TIR domain binding"),
c("GO:0044325","ion channel binding",0.017,0.6422,0.826,0.372,"TIR domain binding"),
c("GO:0019955","cytokine binding",0.021,0.7164,0.825,0.376,"TIR domain binding"),
c("GO:0008013","beta-catenin binding",0.021,0.5856,0.824,0.376,"TIR domain binding"),
c("GO:0019905","syntaxin binding",0.027,0.6909,0.822,0.382,"TIR domain binding"),
c("GO:0019902","phosphatase binding",0.032,0.8208,0.798,0.387,"TIR domain binding"),
c("GO:0030276","clathrin binding",0.033,0.8005,0.820,0.387,"TIR domain binding"),
c("GO:0008022","protein C-terminus binding",0.035,0.6486,0.820,0.388,"TIR domain binding"),
c("GO:0031683","G-protein beta/gamma-subunit complex binding",0.044,0.8163,0.794,0.395,"TIR domain binding"),
c("GO:0000149","SNARE binding",0.047,0.7141,0.816,0.396,"TIR domain binding"),
c("GO:0043130","ubiquitin binding",0.059,0.8158,0.814,0.403,"TIR domain binding"),
c("GO:0005516","calmodulin binding",0.072,0.7895,0.812,0.408,"TIR domain binding"),
c("GO:0019904","protein domain specific binding",0.147,0.7731,0.803,0.434,"TIR domain binding"),
c("GO:0042393","histone binding",0.087,0.6991,0.810,0.440,"TIR domain binding"),
c("GO:0050839","cell adhesion molecule binding",0.088,0.6801,0.809,0.440,"TIR domain binding"),
c("GO:0031072","heat shock protein binding",0.091,0.6118,0.809,0.441,"TIR domain binding"),
c("GO:0051087","chaperone binding",0.101,0.7547,0.808,0.445,"TIR domain binding"),
c("GO:0008017","microtubule binding",0.256,0.7583,0.792,0.478,"TIR domain binding"),
c("GO:0046982","protein heterodimerization activity",0.280,0.7530,0.794,0.504,"TIR domain binding"),
c("GO:0005176","ErbB-2 class receptor binding",0.001,0.6877,0.836,0.515,"TIR domain binding"),
c("GO:0005102","receptor binding",0.420,0.7288,0.789,0.526,"TIR domain binding"),
c("GO:0030215","semaphorin receptor binding",0.002,0.8312,0.830,0.531,"TIR domain binding"),
c("GO:0008134","transcription factor binding",0.320,0.6970,0.793,0.532,"TIR domain binding"),
c("GO:0030169","low-density lipoprotein particle binding",0.003,0.6393,0.943,0.533,"TIR domain binding"),
c("GO:0097016","L27 domain binding",0.001,0.8324,0.841,0.538,"TIR domain binding"),
c("GO:0071535","RING-like zinc finger domain binding",0.000,0.6450,0.845,0.542,"TIR domain binding"),
c("GO:0042802","identical protein binding",0.400,0.6732,0.790,0.543,"TIR domain binding"),
c("GO:0031996","thioesterase binding",0.003,0.6460,0.824,0.543,"TIR domain binding"),
c("GO:0017160","Ral GTPase binding",0.003,0.7719,0.820,0.546,"TIR domain binding"),
c("GO:0008092","cytoskeletal protein binding",0.708,0.7176,0.782,0.573,"TIR domain binding"),
c("GO:0005164","tumor necrosis factor receptor binding",0.011,0.8400,0.813,0.580,"TIR domain binding"),
c("GO:0005112","Notch binding",0.006,0.8240,0.821,0.580,"TIR domain binding"),
c("GO:0051082","unfolded protein binding",0.486,0.7165,0.787,0.581,"TIR domain binding"),
c("GO:0046875","ephrin receptor binding",0.007,0.7571,0.819,0.584,"TIR domain binding"),
c("GO:0031624","ubiquitin conjugating enzyme binding",0.011,0.6057,0.810,0.588,"TIR domain binding"),
c("GO:0051117","ATPase binding",0.014,0.5743,0.808,0.597,"TIR domain binding"),
c("GO:1905394","retromer complex binding",0.001,0.6174,0.833,0.599,"TIR domain binding"),
c("GO:0031489","myosin V binding",0.003,0.5943,0.837,0.605,"TIR domain binding"),
c("GO:0042826","histone deacetylase binding",0.019,0.5922,0.804,0.610,"TIR domain binding"),
c("GO:0019903","protein phosphatase binding",0.022,0.8246,0.803,0.615,"TIR domain binding"),
c("GO:0030165","PDZ domain binding",0.013,0.7285,0.818,0.628,"TIR domain binding"),
c("GO:0046983","protein dimerization activity",1.157,0.6895,0.774,0.634,"TIR domain binding"),
c("GO:0033149","FFAT motif binding",0.002,0.7222,0.835,0.655,"TIR domain binding"),
c("GO:0001664","G-protein coupled receptor binding",0.066,0.7960,0.796,0.663,"TIR domain binding"),
c("GO:0070628","proteasome binding",0.008,0.6912,0.812,0.685,"TIR domain binding"),
c("GO:0050699","WW domain binding",0.004,0.6322,0.828,0.687,"TIR domain binding"),
c("GO:0035257","nuclear hormone receptor binding",0.022,0.7024,0.808,0.692,"TIR domain binding"),
c("GO:0019901","protein kinase binding",0.149,0.7271,0.776,0.695,"TIR domain binding"),
c("GO:0070840","dynein complex binding",0.010,0.8144,0.809,0.696,"TIR domain binding"),
c("GO:0090729","toxin activity",0.004,0.6782,0.994,0.000,"toxin activity"),
c("GO:0016175","superoxide-generating NADPH oxidase activity",0.004,0.8544,0.962,0.014,"superoxide-generating NADPH oxidase activity"),
c("GO:0004597","peptide-aspartate beta-dioxygenase activity",0.001,0.8474,0.959,0.162,"superoxide-generating NADPH oxidase activity"),
c("GO:0047045","testosterone 17-beta-dehydrogenase (NADP+) activity",0.001,0.7905,0.959,0.163,"superoxide-generating NADPH oxidase activity"),
c("GO:0004657","proline dehydrogenase activity",0.028,0.8035,0.955,0.197,"superoxide-generating NADPH oxidase activity"),
c("GO:0004601","peroxidase activity",0.377,0.7198,0.949,0.261,"superoxide-generating NADPH oxidase activity"),
c("GO:0016620","oxidoreductase activity, acting on the aldehyde or oxo group of donors, NAD or NADP as acceptor",0.395,0.6926,0.948,0.323,"superoxide-generating NADPH oxidase activity"),
c("GO:0045703","ketoreductase activity",0.003,0.6521,0.957,0.342,"superoxide-generating NADPH oxidase activity"),
c("GO:0016705","oxidoreductase activity, acting on paired donors, with incorporation or reduction of molecular oxygen",1.177,0.6893,0.947,0.360,"superoxide-generating NADPH oxidase activity"),
c("GO:0102341","3-oxo-lignoceroyl-CoA reductase activity",0.003,0.6472,0.956,0.372,"superoxide-generating NADPH oxidase activity"),
c("GO:0004497","monooxygenase activity",0.947,0.6816,0.948,0.394,"superoxide-generating NADPH oxidase activity"),
c("GO:0102339","3-oxo-arachidoyl-CoA reductase activity",0.003,0.6472,0.956,0.398,"superoxide-generating NADPH oxidase activity"),
c("GO:0102340","3-oxo-behenoyl-CoA reductase activity",0.003,0.6472,0.956,0.398,"superoxide-generating NADPH oxidase activity"),
c("GO:0102342","3-oxo-cerotoyl-CoA reductase activity",0.003,0.6472,0.956,0.398,"superoxide-generating NADPH oxidase activity"),
c("GO:0016715","oxidoreductase activity, acting on paired donors, with incorporation or reduction of molecular oxygen, reduced ascorbate as one donor, and incorporation of one atom of oxygen",0.010,0.8447,0.957,0.412,"superoxide-generating NADPH oxidase activity"),
c("GO:0016614","oxidoreductase activity, acting on CH-OH group of donors",2.016,0.6588,0.945,0.430,"superoxide-generating NADPH oxidase activity"),
c("GO:0045174","glutathione dehydrogenase (ascorbate) activity",0.001,0.6950,0.962,0.568,"superoxide-generating NADPH oxidase activity"),
c("GO:0016702","oxidoreductase activity, acting on single donors with incorporation of molecular oxygen, incorporation of two atoms of oxygen",0.178,0.7500,0.948,0.574,"superoxide-generating NADPH oxidase activity"),
c("GO:0004651","polynucleotide 5'-phosphatase activity",0.007,0.8454,0.914,0.015,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004181","metallocarboxypeptidase activity",0.084,0.7799,0.917,0.140,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004040","amidase activity",0.144,0.7551,0.935,0.171,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004553","hydrolase activity, hydrolyzing O-glycosyl compounds",1.490,0.6686,0.920,0.217,"polynucleotide 5prime-phosphatase activity"),
c("GO:0016810","hydrolase activity, acting on carbon-nitrogen (but not peptide) bonds",1.786,0.6516,0.923,0.283,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004064","arylesterase activity",0.006,0.5863,0.924,0.302,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004525","ribonuclease III activity",0.077,0.7659,0.909,0.349,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004438","phosphatidylinositol-3-phosphatase activity",0.004,0.7499,0.916,0.461,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004435","phosphatidylinositol phospholipase C activity",0.031,0.8220,0.905,0.478,"polynucleotide 5prime-phosphatase activity"),
c("GO:0008234","cysteine-type peptidase activity",0.411,0.7195,0.913,0.510,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004518","nuclease activity",2.144,0.6433,0.888,0.532,"polynucleotide 5prime-phosphatase activity"),
c("GO:0003935","GTP cyclohydrolase II activity",0.033,0.6380,0.941,0.543,"polynucleotide 5prime-phosphatase activity"),
c("GO:0036459","thiol-dependent ubiquitinyl hydrolase activity",0.184,0.6652,0.916,0.544,"polynucleotide 5prime-phosphatase activity"),
c("GO:0008138","protein tyrosine/serine/threonine phosphatase activity",0.094,0.7902,0.897,0.562,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004190","aspartic-type endopeptidase activity",0.269,0.7085,0.912,0.562,"polynucleotide 5prime-phosphatase activity"),
c("GO:0033925","mannosyl-glycoprotein endo-beta-N-acetylglucosaminidase activity",0.006,0.5828,0.944,0.566,"polynucleotide 5prime-phosphatase activity"),
c("GO:0019198","transmembrane receptor protein phosphatase activity",0.001,0.6736,0.855,0.583,"polynucleotide 5prime-phosphatase activity"),
c("GO:0008237","metallopeptidase activity",1.205,0.6299,0.905,0.647,"polynucleotide 5prime-phosphatase activity"),
c("GO:0008810","cellulase activity",0.036,0.7102,0.938,0.648,"polynucleotide 5prime-phosphatase activity"),
c("GO:0003993","acid phosphatase activity",0.088,0.6206,0.900,0.649,"polynucleotide 5prime-phosphatase activity"),
c("GO:0033549","MAP kinase phosphatase activity",0.009,0.7272,0.911,0.650,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004540","ribonuclease activity",0.612,0.6913,0.896,0.655,"polynucleotide 5prime-phosphatase activity"),
c("GO:0008408","3'-5' exonuclease activity",0.342,0.6303,0.900,0.698,"polynucleotide 5prime-phosphatase activity"),
c("GO:0004383","guanylate cyclase activity",0.023,0.8080,0.968,0.016,"guanylate cyclase activity"),
c("GO:0004609","phosphatidylserine decarboxylase activity",0.041,0.7981,0.970,0.396,"guanylate cyclase activity"),
c("GO:0004089","carbonate dehydratase activity",0.070,0.7777,0.969,0.425,"guanylate cyclase activity"),
c("GO:0016849","phosphorus-oxygen lyase activity",0.183,0.7416,0.968,0.472,"guanylate cyclase activity"),
c("GO:0004820","glycine-tRNA ligase activity",0.061,0.7758,0.979,0.018,"glycine-tRNA ligase activity"),
c("GO:0019239","deaminase activity",0.250,0.7334,0.977,0.021,"deaminase activity"),
c("GO:0070300","phosphatidic acid binding",0.004,0.8545,0.925,0.023,"phosphatidic acid binding"),
c("GO:0016595","glutamate binding",0.001,0.6432,0.957,0.114,"phosphatidic acid binding"),
c("GO:0019992","diacylglycerol binding",0.007,0.8506,0.936,0.531,"phosphatidic acid binding"),
c("GO:0032934","sterol binding",0.014,0.8382,0.927,0.566,"phosphatidic acid binding"),
c("GO:0005545","1-phosphatidylinositol binding",0.016,0.8401,0.919,0.627,"phosphatidic acid binding"),
c("GO:0005547","phosphatidylinositol-3,4,5-trisphosphate binding",0.006,0.8057,0.921,0.677,"phosphatidic acid binding"),
c("GO:0009982","pseudouridine synthase activity",0.289,0.7250,0.972,0.024,"pseudouridine synthase activity"),
c("GO:0051120","hepoxilin A3 synthase activity",0.000,0.5783,0.979,0.371,"pseudouridine synthase activity"),
c("GO:0003755","peptidyl-prolyl cis-trans isomerase activity",0.359,0.6432,0.971,0.613,"pseudouridine synthase activity"),
c("GO:0004803","transposase activity",0.307,0.7235,0.977,0.025,"transposase activity"),
c("GO:0001540","beta-amyloid binding",0.007,0.8453,0.966,0.026,"beta-amyloid binding"),
c("GO:0031177","phosphopantetheine binding",0.140,0.7568,0.940,0.679,"beta-amyloid binding"),
c("GO:0003730","mRNA 3'-UTR binding",0.016,0.8342,0.949,0.028,"mRNA 3prime-UTR binding"),
c("GO:0035497","cAMP response element binding",0.005,0.8261,0.948,0.132,"mRNA 3prime-UTR binding"),
c("GO:0003697","single-stranded DNA binding",0.219,0.7343,0.946,0.228,"mRNA 3prime-UTR binding"),
c("GO:0003723","RNA binding",5.283,0.5742,0.935,0.269,"mRNA 3prime-UTR binding"),
c("GO:0003684","damaged DNA binding",0.291,0.7320,0.945,0.304,"mRNA 3prime-UTR binding"),
c("GO:0003747","translation release factor activity",0.135,0.7531,0.944,0.364,"mRNA 3prime-UTR binding"),
c("GO:0043565","sequence-specific DNA binding",2.222,0.6679,0.936,0.376,"mRNA 3prime-UTR binding"),
c("GO:0000049","tRNA binding",0.670,0.6196,0.945,0.480,"mRNA 3prime-UTR binding"),
c("GO:0050840","extracellular matrix binding",0.011,0.7375,0.969,0.029,"extracellular matrix binding"),
c("GO:0035591","signaling adaptor activity",0.013,0.8206,0.960,0.029,"signaling adaptor activity"),
c("GO:0016874","ligase activity",3.540,0.5778,0.973,0.031,"ligase activity"),
c("GO:0008061","chitin binding",0.114,0.7747,0.958,0.034,"chitin binding"),
c("GO:0030552","cAMP binding",0.012,0.7333,0.946,0.184,"chitin binding"),
c("GO:0008201","heparin binding",0.029,0.7185,0.946,0.195,"chitin binding"),
c("GO:0010181","FMN binding",0.698,0.7003,0.921,0.248,"chitin binding"),
c("GO:0043531","ADP binding",0.183,0.6468,0.936,0.264,"chitin binding"),
c("GO:0005525","GTP binding",1.783,0.6624,0.924,0.331,"chitin binding"),
c("GO:0019001","guanyl nucleotide binding",1.846,0.6587,0.940,0.382,"chitin binding"),
c("GO:0071949","FAD binding",0.264,0.6036,0.928,0.499,"chitin binding"),
c("GO:0032550","purine ribonucleoside binding",15.987,0.6577,0.925,0.526,"chitin binding"),
c("GO:0030170","pyridoxal phosphate binding",1.157,0.6727,0.923,0.577,"chitin binding"),
c("GO:0000062","fatty-acyl-CoA binding",0.028,0.5761,0.946,0.632,"chitin binding"),
c("GO:0050662","coenzyme binding",3.468,0.6020,0.939,0.696,"chitin binding"),
c("GO:0030248","cellulose binding",0.033,0.7270,0.967,0.035,"cellulose binding"),
c("GO:0060090","binding, bridging",0.052,0.6238,0.966,0.036,"binding, bridging"),
c("GO:0016829","lyase activity",3.596,0.5766,0.973,0.043,"lyase activity"),
c("GO:0008289","lipid binding",0.519,0.7248,0.961,0.043,"lipid binding"),
c("GO:0030246","carbohydrate binding",0.723,0.7005,0.960,0.051,"carbohydrate binding"),
c("GO:0051539","4 iron, 4 sulfur cluster binding",1.007,0.6679,0.955,0.055,"4 iron, 4 sulfur cluster binding"),
c("GO:0005515","protein binding",4.410,0.6352,0.954,0.067,"protein binding"),
c("GO:0020037","heme binding",1.357,0.6382,0.951,0.080,"heme binding"),
c("GO:0005507","copper ion binding",0.315,0.7257,0.946,0.092,"copper ion binding"),
c("GO:0005509","calcium ion binding",0.967,0.7034,0.944,0.304,"copper ion binding"),
c("GO:0000287","magnesium ion binding",1.785,0.6256,0.941,0.365,"copper ion binding"),
c("GO:0005506","iron ion binding",1.548,0.6742,0.939,0.500,"copper ion binding"),
c("GO:0008270","zinc ion binding",4.511,0.6349,0.934,0.683,"copper ion binding"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
