

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0007155","cell adhesion",0.544,0.7197,0.979,0.000,"cell adhesion"),
c("GO:0007626","locomotory behavior",0.061,0.5053,0.979,0.000,"locomotory behavior"),
c("GO:0009058","biosynthetic process",31.611,0.4994,0.970,0.000,"biosynthesis"),
c("GO:0045214","sarcomere organization",0.013,0.8380,0.657,0.000,"sarcomere organization"),
c("GO:0090090","negative regulation of canonical Wnt signaling pathway",0.025,0.8024,0.674,0.108,"sarcomere organization"),
c("GO:0046716","muscle cell cellular homeostasis",0.006,0.5261,0.837,0.140,"sarcomere organization"),
c("GO:0051301","cell division",1.230,0.5642,0.854,0.147,"sarcomere organization"),
c("GO:0050790","regulation of catalytic activity",1.575,0.5746,0.851,0.203,"sarcomere organization"),
c("GO:0006928","movement of cell or subcellular component",0.973,0.3773,0.856,0.207,"sarcomere organization"),
c("GO:0022402","cell cycle process",1.053,0.4091,0.855,0.209,"sarcomere organization"),
c("GO:0009612","response to mechanical stimulus",0.035,0.4757,0.883,0.227,"sarcomere organization"),
c("GO:0097435","supramolecular fiber organization",0.345,0.6648,0.825,0.333,"sarcomere organization"),
c("GO:0043401","steroid hormone mediated signaling pathway",0.102,0.7921,0.732,0.334,"sarcomere organization"),
c("GO:0060215","primitive hemopoiesis",0.004,0.5277,0.720,0.375,"sarcomere organization"),
c("GO:1902455","negative regulation of stem cell population maintenance",0.001,0.4660,0.638,0.392,"sarcomere organization"),
c("GO:0033339","pectoral fin development",0.003,0.4915,0.736,0.400,"sarcomere organization"),
c("GO:0051289","protein homotetramerization",0.015,0.5498,0.890,0.406,"sarcomere organization"),
c("GO:0070828","heterochromatin organization",0.012,0.4516,0.900,0.411,"sarcomere organization"),
c("GO:0007264","small GTPase mediated signal transduction",0.485,0.7623,0.736,0.415,"sarcomere organization"),
c("GO:0043542","endothelial cell migration",0.033,0.4488,0.762,0.433,"sarcomere organization"),
c("GO:0061448","connective tissue development",0.053,0.5415,0.739,0.434,"sarcomere organization"),
c("GO:1904888","cranial skeletal system development",0.021,0.4911,0.772,0.447,"sarcomere organization"),
c("GO:0007586","digestion",0.026,0.4445,0.831,0.482,"sarcomere organization"),
c("GO:0030154","cell differentiation",1.133,0.6979,0.622,0.579,"sarcomere organization"),
c("GO:1903507","negative regulation of nucleic acid-templated transcription",0.609,0.5069,0.674,0.587,"sarcomere organization"),
c("GO:0032332","positive regulation of chondrocyte differentiation",0.003,0.4584,0.600,0.592,"sarcomere organization"),
c("GO:0035556","intracellular signal transduction",4.000,0.4052,0.695,0.593,"sarcomere organization"),
c("GO:1901223","negative regulation of NIK/NF-kappaB signaling",0.002,0.4382,0.732,0.614,"sarcomere organization"),
c("GO:0030199","collagen fibril organization",0.009,0.4514,0.841,0.618,"sarcomere organization"),
c("GO:0071346","cellular response to interferon-gamma",0.011,0.4798,0.831,0.625,"sarcomere organization"),
c("GO:0001568","blood vessel development",0.136,0.5447,0.673,0.635,"sarcomere organization"),
c("GO:0061061","muscle structure development",0.142,0.5020,0.709,0.637,"sarcomere organization"),
c("GO:0060322","head development",0.151,0.4744,0.708,0.640,"sarcomere organization"),
c("GO:0010718","positive regulation of epithelial to mesenchymal transition",0.008,0.4526,0.582,0.646,"sarcomere organization"),
c("GO:0060271","cilium assembly",0.104,0.5467,0.820,0.649,"sarcomere organization"),
c("GO:0001666","response to hypoxia",0.049,0.4410,0.883,0.659,"sarcomere organization"),
c("GO:0003006","developmental process involved in reproduction",0.296,0.4603,0.724,0.674,"sarcomere organization"),
c("GO:0043124","negative regulation of I-kappaB kinase/NF-kappaB signaling",0.012,0.4670,0.707,0.679,"sarcomere organization"),
c("GO:0006935","chemotaxis",0.475,0.3797,0.841,0.683,"sarcomere organization"),
c("GO:0030512","negative regulation of transforming growth factor beta receptor signaling pathway",0.013,0.5273,0.674,0.695,"sarcomere organization"),
c("GO:0048646","anatomical structure formation involved in morphogenesis",0.409,0.4691,0.723,0.696,"sarcomere organization"),
c("GO:0072488","ammonium transmembrane transport",0.086,0.7731,0.962,0.000,"ammonium transmembrane transport"),
c("GO:0006897","endocytosis",0.235,0.7219,0.961,0.218,"ammonium transmembrane transport"),
c("GO:0034613","cellular protein localization",1.546,0.3993,0.951,0.269,"ammonium transmembrane transport"),
c("GO:0046827","positive regulation of protein export from nucleus",0.006,0.4277,0.824,0.591,"ammonium transmembrane transport"),
c("GO:0006002","fructose 6-phosphate metabolic process",0.060,0.7836,0.889,0.020,"fructose 6-phosphate metabolism"),
c("GO:0030388","fructose 1,6-bisphosphate metabolic process",0.014,0.4461,0.897,0.321,"fructose 6-phosphate metabolism"),
c("GO:0061615","glycolytic process through fructose-6-phosphate",0.061,0.7822,0.772,0.353,"fructose 6-phosphate metabolism"),
c("GO:0006511","ubiquitin-dependent protein catabolic process",0.584,0.4959,0.823,0.468,"fructose 6-phosphate metabolism"),
c("GO:0006735","NADH regeneration",0.002,0.5134,0.835,0.479,"fructose 6-phosphate metabolism"),
c("GO:0061718","glucose catabolic process to pyruvate",0.001,0.5139,0.868,0.514,"fructose 6-phosphate metabolism"),
c("GO:0005978","glycogen biosynthetic process",0.099,0.6249,0.794,0.540,"fructose 6-phosphate metabolism"),
c("GO:0016567","protein ubiquitination",0.523,0.7267,0.812,0.047,"protein ubiquitination"),
c("GO:0006260","DNA replication",1.577,0.6579,0.844,0.150,"protein ubiquitination"),
c("GO:0045893","positive regulation of transcription, DNA-templated",0.519,0.4709,0.706,0.282,"protein ubiquitination"),
c("GO:0006413","translational initiation",0.518,0.4838,0.806,0.317,"protein ubiquitination"),
c("GO:0018377","protein myristoylation",0.009,0.4237,0.836,0.325,"protein ubiquitination"),
c("GO:0035269","protein O-linked mannosylation",0.011,0.5677,0.773,0.330,"protein ubiquitination"),
c("GO:0018149","peptide cross-linking",0.013,0.3653,0.857,0.333,"protein ubiquitination"),
c("GO:0006508","proteolysis",5.223,0.6083,0.854,0.335,"protein ubiquitination"),
c("GO:0018205","peptidyl-lysine modification",0.355,0.4400,0.825,0.434,"protein ubiquitination"),
c("GO:0006470","protein dephosphorylation",0.585,0.7159,0.788,0.455,"protein ubiquitination"),
c("GO:0006355","regulation of transcription, DNA-templated",9.917,0.5805,0.694,0.548,"protein ubiquitination"),
c("GO:0006468","protein phosphorylation",4.137,0.6301,0.758,0.568,"protein ubiquitination"),
c("GO:0016310","phosphorylation",7.764,0.5750,0.865,0.615,"protein ubiquitination"),
c("GO:0006412","translation",5.686,0.4433,0.763,0.661,"protein ubiquitination"),
c("GO:0043065","positive regulation of apoptotic process",0.105,0.4681,0.739,0.673,"protein ubiquitination"),
c("GO:0001935","endothelial cell proliferation",0.022,0.4556,0.929,0.047,"endothelial cell proliferation"),
c("GO:0055114","oxidation-reduction process",15.060,0.5333,0.876,0.079,"oxidation-reduction process"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
