

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0005576","extracellular region",2.375,0.6653,0.945,0.000,"extracellular region"),
c("GO:0005615","extracellular space",0.538,0.4430,0.908,0.000,"extracellular space"),
c("GO:0005604","basement membrane",0.041,0.4105,0.908,0.658,"extracellular space"),
c("GO:0005623","cell",53.553,0.4659,0.974,0.000,"cell"),
c("GO:0005856","cytoskeleton",1.542,0.6909,0.584,0.000,"cytoskeleton"),
c("GO:0005938","cell cortex",0.252,0.6055,0.621,0.131,"cytoskeleton"),
c("GO:0005737","cytoplasm",26.017,0.5152,0.703,0.241,"cytoskeleton"),
c("GO:0045335","phagocytic vesicle",0.028,0.4734,0.688,0.255,"cytoskeleton"),
c("GO:0048471","perinuclear region of cytoplasm",0.135,0.5969,0.714,0.287,"cytoskeleton"),
c("GO:0070013","intracellular organelle lumen",2.741,0.4986,0.610,0.333,"cytoskeleton"),
c("GO:0031226","intrinsic component of plasma membrane",1.299,0.4024,0.781,0.369,"cytoskeleton"),
c("GO:0005829","cytosol",2.553,0.5339,0.649,0.374,"cytoskeleton"),
c("GO:0005884","actin filament",0.037,0.7305,0.603,0.386,"cytoskeleton"),
c("GO:0005783","endoplasmic reticulum",1.332,0.4741,0.594,0.452,"cytoskeleton"),
c("GO:0005739","mitochondrion",2.156,0.3599,0.578,0.481,"cytoskeleton"),
c("GO:0000785","chromatin",0.473,0.4757,0.591,0.489,"cytoskeleton"),
c("GO:0005634","nucleus",8.965,0.6104,0.588,0.547,"cytoskeleton"),
c("GO:0005886","plasma membrane",10.510,0.4396,0.749,0.578,"cytoskeleton"),
c("GO:0005840","ribosome",4.198,0.4865,0.476,0.635,"cytoskeleton"),
c("GO:0030018","Z disc",0.026,0.4025,0.621,0.642,"cytoskeleton"),
c("GO:0015630","microtubule cytoskeleton",0.900,0.4082,0.555,0.651,"cytoskeleton"),
c("GO:0032432","actin filament bundle",0.022,0.4713,0.629,0.672,"cytoskeleton"),
c("GO:0005925","focal adhesion",0.109,0.5453,0.898,0.000,"focal adhesion"),
c("GO:0016020","membrane",61.592,0.4229,0.978,0.000,"membrane"),
c("GO:0016021","integral component of membrane",55.868,0.4341,0.962,0.000,"integral component of membrane"),
c("GO:0061695","transferase complex, transferring phosphorus-containing groups",0.589,0.4149,0.861,0.000,"transferase complex, transferring phosphorus-containing groups"),
c("GO:0005964","phosphorylase kinase complex",0.004,0.3426,0.728,0.571,"transferase complex, transferring phosphorus-containing groups"),
c("GO:0070938","contractile ring",0.014,0.3730,0.881,0.047,"contractile ring"),
c("GO:0005903","brush border",0.023,0.4760,0.879,0.049,"brush border"),
c("GO:0043005","neuron projection",0.190,0.4956,0.867,0.059,"neuron projection"),
c("GO:0032153","cell division site",0.238,0.4152,0.865,0.060,"cell division site"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
