

# A treemap R script produced by the REVIGO server at http://revigo.irb.hr/
# If you found REVIGO useful in your work, please cite the following reference:
# Supek F et al. "REVIGO summarizes and visualizes long lists of Gene Ontology
# terms" PLoS ONE 2011. doi:10.1371/journal.pone.0021800

# author: Anton Kratz <anton.kratz@gmail.com>, RIKEN Omics Science Center, Functional Genomics Technology Team, Japan
# created: Fri, Nov 02, 2012  7:25:52 PM
# last change: Fri, Nov 09, 2012  3:20:01 PM

# -----------------------------------------------------------------------------
# If you don't have the treemap package installed, uncomment the following line:
# install.packages( "treemap" );
library(treemap) 								# treemap package by Martijn Tennekes

# Set the working directory if necessary
# setwd("C:/Users/username/workingdir");

# --------------------------------------------------------------------------
# Here is your data from REVIGO. Scroll down for plot configuration options.

revigo.names <- c("term_ID","description","freqInDbPercent","value","uniqueness","dispensability","representative");
revigo.data <- rbind(c("GO:0003682","chromatin binding",0.220,0.7727,0.919,0.000,"chromatin binding"),
c("GO:0003700","transcription factor activity, sequence-specific DNA binding",4.217,0.6199,0.969,0.000,"transcription factor activity, sequence-specific DNA binding"),
c("GO:0003714","transcription corepressor activity",0.050,0.4963,0.967,0.000,"transcription corepressor activity"),
c("GO:0003735","structural constituent of ribosome",2.679,0.5058,0.949,0.000,"structural constituent of ribosome"),
c("GO:0042302","structural constituent of cuticle",0.063,0.4838,0.948,0.603,"structural constituent of ribosome"),
c("GO:0003950","NAD+ ADP-ribosyltransferase activity",0.033,0.8216,0.904,0.000,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0003810","protein-glutamine gamma-glutamyltransferase activity",0.008,0.3654,0.919,0.142,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0003872","6-phosphofructokinase activity",0.054,0.7879,0.891,0.158,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0004842","ubiquitin-protein transferase activity",0.352,0.7378,0.905,0.187,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0008483","transaminase activity",0.736,0.5739,0.901,0.233,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0004689","phosphorylase kinase activity",0.003,0.3433,0.904,0.325,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0000030","mannosyltransferase activity",0.076,0.5270,0.931,0.505,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0004672","protein kinase activity",3.390,0.6377,0.865,0.534,"NAD+ ADP-ribosyltransferase activity"),
c("GO:0005044","scavenger receptor activity",0.041,0.8175,0.953,0.000,"scavenger receptor activity"),
c("GO:0003707","steroid hormone receptor activity",0.048,0.8017,0.953,0.455,"scavenger receptor activity"),
c("GO:0005085","guanyl-nucleotide exchange factor activity",0.244,0.7555,0.968,0.000,"guanyl-nucleotide exchange factor activity"),
c("GO:0008519","ammonium transmembrane transporter activity",0.086,0.7744,0.968,0.000,"ammonium transmembrane transporter activity"),
c("GO:0004198","calcium-dependent cysteine-type endopeptidase activity",0.033,0.8180,0.891,0.018,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0004722","protein serine/threonine phosphatase activity",0.141,0.7664,0.894,0.160,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0016887","ATPase activity",4.560,0.6145,0.876,0.242,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0008236","serine-type peptidase activity",1.237,0.3822,0.882,0.517,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0003774","motor activity",0.399,0.6101,0.892,0.583,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0003924","GTPase activity",1.135,0.4212,0.885,0.663,"calcium-dependent cysteine-type endopeptidase activity"),
c("GO:0016641","oxidoreductase activity, acting on the CH-NH2 group of donors, oxygen as acceptor",0.161,0.7686,0.952,0.020,"oxidoreductase activity, acting on the CH-NH2 group of donors, oxygen as acceptor"),
c("GO:0016491","oxidoreductase activity",12.783,0.5471,0.947,0.034,"oxidoreductase activity"),
c("GO:0060090","binding, bridging",0.052,0.3854,0.924,0.038,"binding, bridging"),
c("GO:0048029","monosaccharide binding",0.111,0.4273,0.909,0.040,"monosaccharide binding"),
c("GO:0019900","kinase binding",0.164,0.7494,0.764,0.041,"kinase binding"),
c("GO:0070412","R-SMAD binding",0.005,0.4361,0.832,0.364,"kinase binding"),
c("GO:0001103","RNA polymerase II repressing transcription factor binding",0.007,0.5709,0.829,0.372,"kinase binding"),
c("GO:0005516","calmodulin binding",0.072,0.4711,0.808,0.437,"kinase binding"),
c("GO:0003779","actin binding",0.326,0.7405,0.791,0.492,"kinase binding"),
c("GO:0042803","protein homodimerization activity",0.221,0.5730,0.795,0.504,"kinase binding"),
c("GO:0042802","identical protein binding",0.400,0.6931,0.788,0.531,"kinase binding"),
c("GO:0042826","histone deacetylase binding",0.019,0.4620,0.789,0.676,"kinase binding"),
c("GO:0017048","Rho GTPase binding",0.031,0.7040,0.778,0.698,"kinase binding"),
c("GO:0005507","copper ion binding",0.315,0.7248,0.852,0.044,"copper ion binding"),
c("GO:0030170","pyridoxal phosphate binding",1.157,0.6706,0.856,0.142,"copper ion binding"),
c("GO:0070095","fructose-6-phosphate binding",0.000,0.4733,0.913,0.145,"copper ion binding"),
c("GO:0003676","nucleic acid binding",21.226,0.5163,0.863,0.174,"copper ion binding"),
c("GO:0005525","GTP binding",1.783,0.6624,0.841,0.291,"copper ion binding"),
c("GO:0005509","calcium ion binding",0.967,0.7020,0.851,0.304,"copper ion binding"),
c("GO:0000287","magnesium ion binding",1.785,0.6427,0.844,0.365,"copper ion binding"),
c("GO:0030145","manganese ion binding",0.256,0.7236,0.854,0.423,"copper ion binding"),
c("GO:0005524","ATP binding",14.125,0.5528,0.810,0.519,"copper ion binding"),
c("GO:0008270","zinc ion binding",4.511,0.6349,0.819,0.561,"copper ion binding"),
c("GO:0046872","metal ion binding",15.425,0.5432,0.812,0.631,"copper ion binding"),
c("GO:0003690","double-stranded DNA binding",0.508,0.7171,0.867,0.047,"double-stranded DNA binding"),
c("GO:0003743","translation initiation factor activity",0.411,0.4886,0.876,0.227,"double-stranded DNA binding"),
c("GO:0003723","RNA binding",5.283,0.5733,0.848,0.297,"double-stranded DNA binding"),
c("GO:0001012","RNA polymerase II regulatory region DNA binding",0.160,0.4573,0.877,0.310,"double-stranded DNA binding"),
c("GO:0043565","sequence-specific DNA binding",2.222,0.6679,0.852,0.399,"double-stranded DNA binding"),
c("GO:0003677","DNA binding",12.549,0.4442,0.837,0.487,"double-stranded DNA binding"),
c("GO:0030246","carbohydrate binding",0.723,0.4865,0.913,0.051,"carbohydrate binding"),
c("GO:0044877","macromolecular complex binding",0.740,0.4551,0.913,0.053,"macromolecular complex binding"),
c("GO:0005515","protein binding",4.410,0.4253,0.902,0.065,"protein binding"),
c("GO:0016787","hydrolase activity",22.294,0.5239,0.949,0.080,"hydrolase activity"));

stuff <- data.frame(revigo.data);
names(stuff) <- revigo.names;

stuff$value <- as.numeric( as.character(stuff$value) );
stuff$freqInDbPercent <- as.numeric( as.character(stuff$freqInDbPercent) );
stuff$uniqueness <- as.numeric( as.character(stuff$uniqueness) );
stuff$dispensability <- as.numeric( as.character(stuff$dispensability) );

# by default, outputs to a PDF file
pdf( file="revigo_treemap.pdf", width=16, height=9 ) # width and height are in inches

# check the tmPlot command documentation for all possible parameters - there are a lot more
tmPlot(
	stuff,
	index = c("representative","description"),
	vSize = "value",
	type = "categorical",
	vColor = "representative",
	title = "REVIGO Gene Ontology treemap",
	inflate.labels = FALSE,      # set this to TRUE for space-filling group labels - good for posters
	lowerbound.cex.labels = 0,   # try to draw as many labels as possible (still, some small squares may not get a label)
	bg.labels = "#CCCCCCAA",     # define background color of group labels
												       # "#CCCCCC00" is fully transparent, "#CCCCCCAA" is semi-transparent grey, NA is opaque
	position.legend = "none"
)

dev.off()
